/****************************************************************************
** Meta object code from reading C++ file 'engine.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/core/engine.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'engine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNSCore__Engine_t {
    QByteArrayData data[48];
    char stringdata0[888];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNSCore__Engine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNSCore__Engine_t qt_meta_stringdata_KNSCore__Engine = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KNSCore::Engine"
QT_MOC_LITERAL(1, 16, 13), // "signalMessage"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 7), // "message"
QT_MOC_LITERAL(4, 39, 21), // "signalProvidersLoaded"
QT_MOC_LITERAL(5, 61, 19), // "signalEntriesLoaded"
QT_MOC_LITERAL(6, 81, 28), // "KNSCore::EntryInternal::List"
QT_MOC_LITERAL(7, 110, 7), // "entries"
QT_MOC_LITERAL(8, 118, 29), // "signalUpdateableEntriesLoaded"
QT_MOC_LITERAL(9, 148, 18), // "signalEntryChanged"
QT_MOC_LITERAL(10, 167, 22), // "KNSCore::EntryInternal"
QT_MOC_LITERAL(11, 190, 5), // "entry"
QT_MOC_LITERAL(12, 196, 24), // "signalEntryDetailsLoaded"
QT_MOC_LITERAL(13, 221, 15), // "signalResetView"
QT_MOC_LITERAL(14, 237, 24), // "signalEntryPreviewLoaded"
QT_MOC_LITERAL(15, 262, 35), // "KNSCore::EntryInternal::Previ..."
QT_MOC_LITERAL(16, 298, 19), // "signalPreviewFailed"
QT_MOC_LITERAL(17, 318, 25), // "signalEntryUploadFinished"
QT_MOC_LITERAL(18, 344, 23), // "signalEntryUploadFailed"
QT_MOC_LITERAL(19, 368, 24), // "signalDownloadDialogDone"
QT_MOC_LITERAL(20, 393, 10), // "jobStarted"
QT_MOC_LITERAL(21, 404, 5), // "KJob*"
QT_MOC_LITERAL(22, 410, 11), // "signalError"
QT_MOC_LITERAL(23, 422, 10), // "signalBusy"
QT_MOC_LITERAL(24, 433, 10), // "signalIdle"
QT_MOC_LITERAL(25, 444, 29), // "signalCategoriesMetadataLoded"
QT_MOC_LITERAL(26, 474, 33), // "QList<Provider::CategoryMetad..."
QT_MOC_LITERAL(27, 508, 10), // "categories"
QT_MOC_LITERAL(28, 519, 22), // "slotProviderFileLoaded"
QT_MOC_LITERAL(29, 542, 12), // "QDomDocument"
QT_MOC_LITERAL(30, 555, 3), // "doc"
QT_MOC_LITERAL(31, 559, 20), // "atticaProviderLoaded"
QT_MOC_LITERAL(32, 580, 16), // "Attica::Provider"
QT_MOC_LITERAL(33, 597, 8), // "provider"
QT_MOC_LITERAL(34, 606, 19), // "slotProvidersFailed"
QT_MOC_LITERAL(35, 626, 19), // "providerInitialized"
QT_MOC_LITERAL(36, 646, 18), // "KNSCore::Provider*"
QT_MOC_LITERAL(37, 665, 17), // "slotEntriesLoaded"
QT_MOC_LITERAL(38, 683, 32), // "KNSCore::Provider::SearchRequest"
QT_MOC_LITERAL(39, 716, 22), // "slotEntryDetailsLoaded"
QT_MOC_LITERAL(40, 739, 17), // "slotPreviewLoaded"
QT_MOC_LITERAL(41, 757, 4), // "type"
QT_MOC_LITERAL(42, 762, 22), // "slotSearchTimerExpired"
QT_MOC_LITERAL(43, 785, 16), // "slotEntryChanged"
QT_MOC_LITERAL(44, 802, 24), // "slotInstallationFinished"
QT_MOC_LITERAL(45, 827, 22), // "slotInstallationFailed"
QT_MOC_LITERAL(46, 850, 18), // "downloadLinkLoaded"
QT_MOC_LITERAL(47, 869, 18) // "providerJobStarted"

    },
    "KNSCore::Engine\0signalMessage\0\0message\0"
    "signalProvidersLoaded\0signalEntriesLoaded\0"
    "KNSCore::EntryInternal::List\0entries\0"
    "signalUpdateableEntriesLoaded\0"
    "signalEntryChanged\0KNSCore::EntryInternal\0"
    "entry\0signalEntryDetailsLoaded\0"
    "signalResetView\0signalEntryPreviewLoaded\0"
    "KNSCore::EntryInternal::PreviewType\0"
    "signalPreviewFailed\0signalEntryUploadFinished\0"
    "signalEntryUploadFailed\0"
    "signalDownloadDialogDone\0jobStarted\0"
    "KJob*\0signalError\0signalBusy\0signalIdle\0"
    "signalCategoriesMetadataLoded\0"
    "QList<Provider::CategoryMetadata>\0"
    "categories\0slotProviderFileLoaded\0"
    "QDomDocument\0doc\0atticaProviderLoaded\0"
    "Attica::Provider\0provider\0slotProvidersFailed\0"
    "providerInitialized\0KNSCore::Provider*\0"
    "slotEntriesLoaded\0KNSCore::Provider::SearchRequest\0"
    "slotEntryDetailsLoaded\0slotPreviewLoaded\0"
    "type\0slotSearchTimerExpired\0"
    "slotEntryChanged\0slotInstallationFinished\0"
    "slotInstallationFailed\0downloadLinkLoaded\0"
    "providerJobStarted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNSCore__Engine[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      17,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  164,    2, 0x06 /* Public */,
       4,    0,  167,    2, 0x06 /* Public */,
       5,    1,  168,    2, 0x06 /* Public */,
       8,    1,  171,    2, 0x06 /* Public */,
       9,    1,  174,    2, 0x06 /* Public */,
      12,    1,  177,    2, 0x06 /* Public */,
      13,    0,  180,    2, 0x06 /* Public */,
      14,    2,  181,    2, 0x06 /* Public */,
      16,    0,  186,    2, 0x06 /* Public */,
      17,    0,  187,    2, 0x06 /* Public */,
      18,    0,  188,    2, 0x06 /* Public */,
      19,    1,  189,    2, 0x06 /* Public */,
      20,    2,  192,    2, 0x06 /* Public */,
      22,    1,  197,    2, 0x06 /* Public */,
      23,    1,  200,    2, 0x06 /* Public */,
      24,    1,  203,    2, 0x06 /* Public */,
      25,    1,  206,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      28,    1,  209,    2, 0x08 /* Private */,
      31,    1,  212,    2, 0x08 /* Private */,
      34,    0,  215,    2, 0x08 /* Private */,
      35,    1,  216,    2, 0x08 /* Private */,
      37,    2,  219,    2, 0x08 /* Private */,
      39,    1,  224,    2, 0x08 /* Private */,
      40,    2,  227,    2, 0x08 /* Private */,
      42,    0,  232,    2, 0x08 /* Private */,
      43,    1,  233,    2, 0x08 /* Private */,
      44,    0,  236,    2, 0x08 /* Private */,
      45,    1,  237,    2, 0x08 /* Private */,
      46,    1,  240,    2, 0x08 /* Private */,
      47,    1,  243,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 15,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 21, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 26,   27,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, 0x80000000 | 32,   33,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 36,    2,
    QMetaType::Void, 0x80000000 | 38, 0x80000000 | 6,    2,    2,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 15,   11,   41,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 21,    2,

       0        // eod
};

void KNSCore::Engine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Engine *_t = static_cast<Engine *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->signalProvidersLoaded(); break;
        case 2: _t->signalEntriesLoaded((*reinterpret_cast< const KNSCore::EntryInternal::List(*)>(_a[1]))); break;
        case 3: _t->signalUpdateableEntriesLoaded((*reinterpret_cast< const KNSCore::EntryInternal::List(*)>(_a[1]))); break;
        case 4: _t->signalEntryChanged((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 5: _t->signalEntryDetailsLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 6: _t->signalResetView(); break;
        case 7: _t->signalEntryPreviewLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1])),(*reinterpret_cast< KNSCore::EntryInternal::PreviewType(*)>(_a[2]))); break;
        case 8: _t->signalPreviewFailed(); break;
        case 9: _t->signalEntryUploadFinished(); break;
        case 10: _t->signalEntryUploadFailed(); break;
        case 11: _t->signalDownloadDialogDone((*reinterpret_cast< KNSCore::EntryInternal::List(*)>(_a[1]))); break;
        case 12: _t->jobStarted((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 13: _t->signalError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->signalBusy((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->signalIdle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->signalCategoriesMetadataLoded((*reinterpret_cast< const QList<Provider::CategoryMetadata>(*)>(_a[1]))); break;
        case 17: _t->slotProviderFileLoaded((*reinterpret_cast< const QDomDocument(*)>(_a[1]))); break;
        case 18: _t->atticaProviderLoaded((*reinterpret_cast< const Attica::Provider(*)>(_a[1]))); break;
        case 19: _t->slotProvidersFailed(); break;
        case 20: _t->providerInitialized((*reinterpret_cast< KNSCore::Provider*(*)>(_a[1]))); break;
        case 21: _t->slotEntriesLoaded((*reinterpret_cast< const KNSCore::Provider::SearchRequest(*)>(_a[1])),(*reinterpret_cast< KNSCore::EntryInternal::List(*)>(_a[2]))); break;
        case 22: _t->slotEntryDetailsLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 23: _t->slotPreviewLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1])),(*reinterpret_cast< KNSCore::EntryInternal::PreviewType(*)>(_a[2]))); break;
        case 24: _t->slotSearchTimerExpired(); break;
        case 25: _t->slotEntryChanged((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 26: _t->slotInstallationFinished(); break;
        case 27: _t->slotInstallationFailed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 28: _t->downloadLinkLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 29: _t->providerJobStarted((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal::List >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal::List >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal::List >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::Provider* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal::List >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Engine::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalMessage)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Engine::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalProvidersLoaded)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const KNSCore::EntryInternal::List & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalEntriesLoaded)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const KNSCore::EntryInternal::List & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalUpdateableEntriesLoaded)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const KNSCore::EntryInternal & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalEntryChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const KNSCore::EntryInternal & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalEntryDetailsLoaded)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Engine::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalResetView)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const KNSCore::EntryInternal & , KNSCore::EntryInternal::PreviewType );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalEntryPreviewLoaded)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Engine::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalPreviewFailed)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Engine::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalEntryUploadFinished)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Engine::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalEntryUploadFailed)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(KNSCore::EntryInternal::List );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalDownloadDialogDone)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(KJob * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::jobStarted)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalError)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalBusy)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalIdle)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (Engine::*_t)(const QList<Provider::CategoryMetadata> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Engine::signalCategoriesMetadataLoded)) {
                *result = 16;
                return;
            }
        }
    }
}

const QMetaObject KNSCore::Engine::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KNSCore__Engine.data,
      qt_meta_data_KNSCore__Engine,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNSCore::Engine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSCore::Engine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNSCore__Engine.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNSCore::Engine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void KNSCore::Engine::signalMessage(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KNSCore::Engine::signalProvidersLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KNSCore::Engine::signalEntriesLoaded(const KNSCore::EntryInternal::List & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KNSCore::Engine::signalUpdateableEntriesLoaded(const KNSCore::EntryInternal::List & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KNSCore::Engine::signalEntryChanged(const KNSCore::EntryInternal & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KNSCore::Engine::signalEntryDetailsLoaded(const KNSCore::EntryInternal & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KNSCore::Engine::signalResetView()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KNSCore::Engine::signalEntryPreviewLoaded(const KNSCore::EntryInternal & _t1, KNSCore::EntryInternal::PreviewType _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KNSCore::Engine::signalPreviewFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KNSCore::Engine::signalEntryUploadFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KNSCore::Engine::signalEntryUploadFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KNSCore::Engine::signalDownloadDialogDone(KNSCore::EntryInternal::List _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KNSCore::Engine::jobStarted(KJob * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KNSCore::Engine::signalError(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void KNSCore::Engine::signalBusy(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void KNSCore::Engine::signalIdle(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void KNSCore::Engine::signalCategoriesMetadataLoded(const QList<Provider::CategoryMetadata> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
