/****************************************************************************
** Meta object code from reading C++ file 'provider.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/core/provider.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'provider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNSCore__Provider_t {
    QByteArrayData data[26];
    char stringdata0[388];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNSCore__Provider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNSCore__Provider_t qt_meta_stringdata_KNSCore__Provider = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KNSCore::Provider"
QT_MOC_LITERAL(1, 18, 19), // "providerInitialized"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 18), // "KNSCore::Provider*"
QT_MOC_LITERAL(4, 58, 15), // "loadingFinished"
QT_MOC_LITERAL(5, 74, 32), // "KNSCore::Provider::SearchRequest"
QT_MOC_LITERAL(6, 107, 28), // "KNSCore::EntryInternal::List"
QT_MOC_LITERAL(7, 136, 13), // "loadingFailed"
QT_MOC_LITERAL(8, 150, 18), // "entryDetailsLoaded"
QT_MOC_LITERAL(9, 169, 22), // "KNSCore::EntryInternal"
QT_MOC_LITERAL(10, 192, 17), // "payloadLinkLoaded"
QT_MOC_LITERAL(11, 210, 17), // "signalInformation"
QT_MOC_LITERAL(12, 228, 11), // "signalError"
QT_MOC_LITERAL(13, 240, 23), // "categoriesMetadataLoded"
QT_MOC_LITERAL(14, 264, 23), // "QList<CategoryMetadata>"
QT_MOC_LITERAL(15, 288, 10), // "categories"
QT_MOC_LITERAL(16, 299, 8), // "SortMode"
QT_MOC_LITERAL(17, 308, 6), // "Newest"
QT_MOC_LITERAL(18, 315, 12), // "Alphabetical"
QT_MOC_LITERAL(19, 328, 6), // "Rating"
QT_MOC_LITERAL(20, 335, 9), // "Downloads"
QT_MOC_LITERAL(21, 345, 6), // "Filter"
QT_MOC_LITERAL(22, 352, 4), // "None"
QT_MOC_LITERAL(23, 357, 9), // "Installed"
QT_MOC_LITERAL(24, 367, 7), // "Updates"
QT_MOC_LITERAL(25, 375, 12) // "ExactEntryId"

    },
    "KNSCore::Provider\0providerInitialized\0"
    "\0KNSCore::Provider*\0loadingFinished\0"
    "KNSCore::Provider::SearchRequest\0"
    "KNSCore::EntryInternal::List\0loadingFailed\0"
    "entryDetailsLoaded\0KNSCore::EntryInternal\0"
    "payloadLinkLoaded\0signalInformation\0"
    "signalError\0categoriesMetadataLoded\0"
    "QList<CategoryMetadata>\0categories\0"
    "SortMode\0Newest\0Alphabetical\0Rating\0"
    "Downloads\0Filter\0None\0Installed\0Updates\0"
    "ExactEntryId"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNSCore__Provider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       2,   80, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    2,   57,    2, 0x06 /* Public */,
       7,    1,   62,    2, 0x06 /* Public */,
       8,    1,   65,    2, 0x06 /* Public */,
      10,    1,   68,    2, 0x06 /* Public */,
      11,    1,   71,    2, 0x06 /* Public */,
      12,    1,   74,    2, 0x06 /* Public */,
      13,    1,   77,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 6,    2,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 14,   15,

 // enums: name, flags, count, data
      16, 0x0,    4,   88,
      21, 0x0,    4,   96,

 // enum data: key, value
      17, uint(KNSCore::Provider::Newest),
      18, uint(KNSCore::Provider::Alphabetical),
      19, uint(KNSCore::Provider::Rating),
      20, uint(KNSCore::Provider::Downloads),
      22, uint(KNSCore::Provider::None),
      23, uint(KNSCore::Provider::Installed),
      24, uint(KNSCore::Provider::Updates),
      25, uint(KNSCore::Provider::ExactEntryId),

       0        // eod
};

void KNSCore::Provider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Provider *_t = static_cast<Provider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->providerInitialized((*reinterpret_cast< KNSCore::Provider*(*)>(_a[1]))); break;
        case 1: _t->loadingFinished((*reinterpret_cast< const KNSCore::Provider::SearchRequest(*)>(_a[1])),(*reinterpret_cast< const KNSCore::EntryInternal::List(*)>(_a[2]))); break;
        case 2: _t->loadingFailed((*reinterpret_cast< const KNSCore::Provider::SearchRequest(*)>(_a[1]))); break;
        case 3: _t->entryDetailsLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 4: _t->payloadLinkLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 5: _t->signalInformation((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->signalError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->categoriesMetadataLoded((*reinterpret_cast< const QList<CategoryMetadata>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::Provider* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal::List >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Provider::*_t)(KNSCore::Provider * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::providerInitialized)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Provider::*_t)(const KNSCore::Provider::SearchRequest & , const KNSCore::EntryInternal::List & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::loadingFinished)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Provider::*_t)(const KNSCore::Provider::SearchRequest & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::loadingFailed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Provider::*_t)(const KNSCore::EntryInternal & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::entryDetailsLoaded)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Provider::*_t)(const KNSCore::EntryInternal & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::payloadLinkLoaded)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Provider::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::signalInformation)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Provider::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::signalError)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Provider::*_t)(const QList<CategoryMetadata> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Provider::categoriesMetadataLoded)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject KNSCore::Provider::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KNSCore__Provider.data,
      qt_meta_data_KNSCore__Provider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNSCore::Provider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSCore::Provider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNSCore__Provider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNSCore::Provider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KNSCore::Provider::providerInitialized(KNSCore::Provider * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KNSCore::Provider::loadingFinished(const KNSCore::Provider::SearchRequest & _t1, const KNSCore::EntryInternal::List & _t2)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(const_cast< KNSCore::Provider *>(this), &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KNSCore::Provider::loadingFailed(const KNSCore::Provider::SearchRequest & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KNSCore::Provider::entryDetailsLoaded(const KNSCore::EntryInternal & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KNSCore::Provider::payloadLinkLoaded(const KNSCore::EntryInternal & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KNSCore::Provider::signalInformation(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< KNSCore::Provider *>(this), &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KNSCore::Provider::signalError(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< KNSCore::Provider *>(this), &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KNSCore::Provider::categoriesMetadataLoded(const QList<CategoryMetadata> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
