/****************************************************************************
** Meta object code from reading C++ file 'security.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/core/security.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'security.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNSCore__Security_t {
    QByteArrayData data[16];
    char stringdata0[219];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNSCore__Security_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNSCore__Security_t qt_meta_stringdata_KNSCore__Security = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KNSCore::Security"
QT_MOC_LITERAL(1, 18, 14), // "validityResult"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 6), // "result"
QT_MOC_LITERAL(4, 41, 10), // "fileSigned"
QT_MOC_LITERAL(5, 52, 17), // "signalInformation"
QT_MOC_LITERAL(6, 70, 11), // "signalError"
QT_MOC_LITERAL(7, 82, 8), // "readKeys"
QT_MOC_LITERAL(8, 91, 14), // "readSecretKeys"
QT_MOC_LITERAL(9, 106, 17), // "slotCheckValidity"
QT_MOC_LITERAL(10, 124, 12), // "slotSignFile"
QT_MOC_LITERAL(11, 137, 12), // "slotFinished"
QT_MOC_LITERAL(12, 150, 8), // "exitCode"
QT_MOC_LITERAL(13, 159, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(14, 180, 10), // "exitStatus"
QT_MOC_LITERAL(15, 191, 27) // "slotReadyReadStandardOutput"

    },
    "KNSCore::Security\0validityResult\0\0"
    "result\0fileSigned\0signalInformation\0"
    "signalError\0readKeys\0readSecretKeys\0"
    "slotCheckValidity\0slotSignFile\0"
    "slotFinished\0exitCode\0QProcess::ExitStatus\0"
    "exitStatus\0slotReadyReadStandardOutput"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNSCore__Security[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,
       5,    1,   70,    2, 0x06 /* Public */,
       6,    1,   73,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   76,    2, 0x0a /* Public */,
       8,    0,   77,    2, 0x0a /* Public */,
       9,    0,   78,    2, 0x0a /* Public */,
      10,    0,   79,    2, 0x0a /* Public */,
      11,    2,   80,    2, 0x08 /* Private */,
      15,    0,   85,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 13,   12,   14,
    QMetaType::Void,

       0        // eod
};

void KNSCore::Security::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Security *_t = static_cast<Security *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->validityResult((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->fileSigned((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->signalInformation((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->signalError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->readKeys(); break;
        case 5: _t->readSecretKeys(); break;
        case 6: _t->slotCheckValidity(); break;
        case 7: _t->slotSignFile(); break;
        case 8: _t->slotFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 9: _t->slotReadyReadStandardOutput(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Security::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Security::validityResult)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Security::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Security::fileSigned)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Security::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Security::signalInformation)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Security::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Security::signalError)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject KNSCore::Security::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KNSCore__Security.data,
      qt_meta_data_KNSCore__Security,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNSCore::Security::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSCore::Security::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNSCore__Security.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNSCore::Security::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KNSCore::Security::validityResult(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KNSCore::Security::fileSigned(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KNSCore::Security::signalInformation(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< KNSCore::Security *>(this), &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KNSCore::Security::signalError(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< KNSCore::Security *>(this), &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
