/****************************************************************************
** Meta object code from reading C++ file 'quickitemsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/qtquick/quickitemsmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quickitemsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ItemsModel_t {
    QByteArrayData data[15];
    char stringdata0[188];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ItemsModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ItemsModel_t qt_meta_stringdata_ItemsModel = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ItemsModel"
QT_MOC_LITERAL(1, 11, 13), // "engineChanged"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 11), // "installItem"
QT_MOC_LITERAL(4, 38, 5), // "index"
QT_MOC_LITERAL(5, 44, 13), // "uninstallItem"
QT_MOC_LITERAL(6, 58, 6), // "engine"
QT_MOC_LITERAL(7, 65, 10), // "ItemStatus"
QT_MOC_LITERAL(8, 76, 13), // "InvalidStatus"
QT_MOC_LITERAL(9, 90, 18), // "DownloadableStatus"
QT_MOC_LITERAL(10, 109, 15), // "InstalledStatus"
QT_MOC_LITERAL(11, 125, 16), // "UpdateableStatus"
QT_MOC_LITERAL(12, 142, 13), // "DeletedStatus"
QT_MOC_LITERAL(13, 156, 16), // "InstallingStatus"
QT_MOC_LITERAL(14, 173, 14) // "UpdatingStatus"

    },
    "ItemsModel\0engineChanged\0\0installItem\0"
    "index\0uninstallItem\0engine\0ItemStatus\0"
    "InvalidStatus\0DownloadableStatus\0"
    "InstalledStatus\0UpdateableStatus\0"
    "DeletedStatus\0InstallingStatus\0"
    "UpdatingStatus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ItemsModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       1,   36, // properties
       1,   40, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
       3,    1,   30,    2, 0x02 /* Public */,
       5,    1,   33,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,

 // properties: name, type, flags
       6, QMetaType::QObjectStar, 0x00495103,

 // properties: notify_signal_id
       0,

 // enums: name, flags, count, data
       7, 0x0,    7,   44,

 // enum data: key, value
       8, uint(ItemsModel::InvalidStatus),
       9, uint(ItemsModel::DownloadableStatus),
      10, uint(ItemsModel::InstalledStatus),
      11, uint(ItemsModel::UpdateableStatus),
      12, uint(ItemsModel::DeletedStatus),
      13, uint(ItemsModel::InstallingStatus),
      14, uint(ItemsModel::UpdatingStatus),

       0        // eod
};

void ItemsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ItemsModel *_t = static_cast<ItemsModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->engineChanged(); break;
        case 1: _t->installItem((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->uninstallItem((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ItemsModel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ItemsModel::engineChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        ItemsModel *_t = static_cast<ItemsModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QObject**>(_v) = _t->engine(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        ItemsModel *_t = static_cast<ItemsModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEngine(*reinterpret_cast< QObject**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject ItemsModel::staticMetaObject = {
    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_ItemsModel.data,
      qt_meta_data_ItemsModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ItemsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ItemsModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int ItemsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ItemsModel::engineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
