/****************************************************************************
** Meta object code from reading C++ file 'itemsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/core/itemsmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNSCore__ItemsModel_t {
    QByteArrayData data[15];
    char stringdata0[222];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNSCore__ItemsModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNSCore__ItemsModel_t qt_meta_stringdata_KNSCore__ItemsModel = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KNSCore::ItemsModel"
QT_MOC_LITERAL(1, 20, 10), // "jobStarted"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 5), // "KJob*"
QT_MOC_LITERAL(4, 38, 5), // "label"
QT_MOC_LITERAL(5, 44, 16), // "slotEntryChanged"
QT_MOC_LITERAL(6, 61, 22), // "KNSCore::EntryInternal"
QT_MOC_LITERAL(7, 84, 5), // "entry"
QT_MOC_LITERAL(8, 90, 17), // "slotEntriesLoaded"
QT_MOC_LITERAL(9, 108, 28), // "KNSCore::EntryInternal::List"
QT_MOC_LITERAL(10, 137, 7), // "entries"
QT_MOC_LITERAL(11, 145, 12), // "clearEntries"
QT_MOC_LITERAL(12, 158, 22), // "slotEntryPreviewLoaded"
QT_MOC_LITERAL(13, 181, 35), // "KNSCore::EntryInternal::Previ..."
QT_MOC_LITERAL(14, 217, 4) // "type"

    },
    "KNSCore::ItemsModel\0jobStarted\0\0KJob*\0"
    "label\0slotEntryChanged\0KNSCore::EntryInternal\0"
    "entry\0slotEntriesLoaded\0"
    "KNSCore::EntryInternal::List\0entries\0"
    "clearEntries\0slotEntryPreviewLoaded\0"
    "KNSCore::EntryInternal::PreviewType\0"
    "type"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNSCore__ItemsModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   44,    2, 0x0a /* Public */,
       8,    1,   47,    2, 0x0a /* Public */,
      11,    0,   50,    2, 0x0a /* Public */,
      12,    2,   51,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 13,    7,   14,

       0        // eod
};

void KNSCore::ItemsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ItemsModel *_t = static_cast<ItemsModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->jobStarted((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->slotEntryChanged((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 2: _t->slotEntriesLoaded((*reinterpret_cast< const KNSCore::EntryInternal::List(*)>(_a[1]))); break;
        case 3: _t->clearEntries(); break;
        case 4: _t->slotEntryPreviewLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1])),(*reinterpret_cast< KNSCore::EntryInternal::PreviewType(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal::List >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNSCore::EntryInternal >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ItemsModel::*_t)(KJob * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ItemsModel::jobStarted)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KNSCore::ItemsModel::staticMetaObject = {
    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_KNSCore__ItemsModel.data,
      qt_meta_data_KNSCore__ItemsModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNSCore::ItemsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSCore::ItemsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNSCore__ItemsModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KNSCore::ItemsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KNSCore::ItemsModel::jobStarted(KJob * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
