/****************************************************************************
** Meta object code from reading C++ file 'entrydetailsdialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knewstuff-5.43.0/src/ui/entrydetailsdialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'entrydetailsdialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNS3__EntryDetails_t {
    QByteArrayData data[19];
    char stringdata0[268];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNS3__EntryDetails_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNS3__EntryDetails_t qt_meta_stringdata_KNS3__EntryDetails = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KNS3::EntryDetails"
QT_MOC_LITERAL(1, 19, 8), // "setEntry"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 22), // "KNSCore::EntryInternal"
QT_MOC_LITERAL(4, 52, 5), // "entry"
QT_MOC_LITERAL(5, 58, 22), // "slotEntryPreviewLoaded"
QT_MOC_LITERAL(6, 81, 35), // "KNSCore::EntryInternal::Previ..."
QT_MOC_LITERAL(7, 117, 4), // "type"
QT_MOC_LITERAL(8, 122, 7), // "install"
QT_MOC_LITERAL(9, 130, 9), // "uninstall"
QT_MOC_LITERAL(10, 140, 13), // "ratingChanged"
QT_MOC_LITERAL(11, 154, 6), // "rating"
QT_MOC_LITERAL(12, 161, 9), // "becomeFan"
QT_MOC_LITERAL(13, 171, 12), // "entryChanged"
QT_MOC_LITERAL(14, 184, 18), // "entryStatusChanged"
QT_MOC_LITERAL(15, 203, 13), // "updateButtons"
QT_MOC_LITERAL(16, 217, 16), // "preview1Selected"
QT_MOC_LITERAL(17, 234, 16), // "preview2Selected"
QT_MOC_LITERAL(18, 251, 16) // "preview3Selected"

    },
    "KNS3::EntryDetails\0setEntry\0\0"
    "KNSCore::EntryInternal\0entry\0"
    "slotEntryPreviewLoaded\0"
    "KNSCore::EntryInternal::PreviewType\0"
    "type\0install\0uninstall\0ratingChanged\0"
    "rating\0becomeFan\0entryChanged\0"
    "entryStatusChanged\0updateButtons\0"
    "preview1Selected\0preview2Selected\0"
    "preview3Selected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNS3__EntryDetails[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x0a /* Public */,
       5,    2,   77,    2, 0x08 /* Private */,
       8,    0,   82,    2, 0x08 /* Private */,
       9,    0,   83,    2, 0x08 /* Private */,
      10,    1,   84,    2, 0x08 /* Private */,
      12,    0,   87,    2, 0x08 /* Private */,
      13,    1,   88,    2, 0x08 /* Private */,
      14,    1,   91,    2, 0x08 /* Private */,
      15,    0,   94,    2, 0x08 /* Private */,
      16,    0,   95,    2, 0x08 /* Private */,
      17,    0,   96,    2, 0x08 /* Private */,
      18,    0,   97,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 6,    4,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,   11,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KNS3::EntryDetails::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        EntryDetails *_t = static_cast<EntryDetails *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setEntry((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 1: _t->slotEntryPreviewLoaded((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1])),(*reinterpret_cast< KNSCore::EntryInternal::PreviewType(*)>(_a[2]))); break;
        case 2: _t->install(); break;
        case 3: _t->uninstall(); break;
        case 4: _t->ratingChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 5: _t->becomeFan(); break;
        case 6: _t->entryChanged((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 7: _t->entryStatusChanged((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 8: _t->updateButtons(); break;
        case 9: _t->preview1Selected(); break;
        case 10: _t->preview2Selected(); break;
        case 11: _t->preview3Selected(); break;
        default: ;
        }
    }
}

const QMetaObject KNS3::EntryDetails::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KNS3__EntryDetails.data,
      qt_meta_data_KNS3__EntryDetails,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNS3::EntryDetails::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNS3::EntryDetails::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNS3__EntryDetails.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNS3::EntryDetails::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
