#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'uploaddialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UPLOADDIALOG_H
#define UI_UPLOADDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "ktextedit.h"
#include "ktitlewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_UploadDialog
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *mTitleWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *busyLabel;
    QWidget *busyWidget;
    QStackedWidget *stackedWidget;
    QWidget *page_3;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer_2;
    QLineEdit *password;
    QLabel *label_11;
    QLabel *label_10;
    QComboBox *providerComboBox;
    QLineEdit *username;
    QLabel *label_9;
    QLabel *registerNewAccountLabel;
    QWidget *page_5;
    QVBoxLayout *verticalLayout_4;
    QLabel *uploadFileLabel;
    KUrlRequester *uploadFileRequester;
    QRadioButton *radioNewUpload;
    QRadioButton *radioUpdate;
    QListWidget *userContentList;
    QWidget *page;
    QGridLayout *gridLayout;
    KTextEdit *mSummaryEdit;
    KComboBox *mLicenseCombo;
    QLabel *label_8;
    QLabel *priceLabel_2;
    QLabel *label_5;
    QLabel *label_6;
    QLabel *label_12;
    QLineEdit *mVersionEdit;
    QLabel *label_4;
    KTextEdit *changelog;
    QLabel *mCategoryLabel;
    QLineEdit *mNameEdit;
    KComboBox *mCategoryCombo;
    QWidget *page_4;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_5;
    QPushButton *changePreview1Button;
    QPushButton *changePreview3Button;
    QPushButton *changePreview2Button;
    QLabel *previewImage1;
    QLabel *previewImage2;
    QLabel *previewImage3;
    QCheckBox *priceCheckBox;
    QGroupBox *priceGroupBox;
    QGridLayout *gridLayout_2;
    QLabel *priceLabel;
    QDoubleSpinBox *priceSpinBox;
    QLabel *priceCurrency;
    QLabel *priceReasonLabel;
    QLineEdit *priceReasonLineEdit;
    QSpacerItem *verticalSpacer_3;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout_4;
    QLabel *createContentImageLabel;
    QLabel *uploadContentImageLabel;
    QLabel *uploadPreview1ImageLabel;
    QLabel *fetchContentLinkImageLabel;
    QLabel *contentWebsiteLinkLabel;
    QLabel *creatingContentLabel;
    QLabel *creatingContentLabel_2;
    QLabel *uploadPreview1Label;
    QLabel *contentWebsiteLink;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QLabel *uploadPreview2Label;
    QLabel *uploadPreview3Label;
    QLabel *uploadPreview2ImageLabel;
    QLabel *uploadPreview3ImageLabel;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *uploadButton;
    QProgressBar *uploadProgressBar;

    void setupUi(QWidget *UploadDialog)
    {
        if (UploadDialog->objectName().isEmpty())
            UploadDialog->setObjectName(QStringLiteral("UploadDialog"));
        UploadDialog->resize(538, 395);
        verticalLayout = new QVBoxLayout(UploadDialog);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        mTitleWidget = new KTitleWidget(UploadDialog);
        mTitleWidget->setObjectName(QStringLiteral("mTitleWidget"));

        verticalLayout->addWidget(mTitleWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        busyLabel = new QLabel(UploadDialog);
        busyLabel->setObjectName(QStringLiteral("busyLabel"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(busyLabel->sizePolicy().hasHeightForWidth());
        busyLabel->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(busyLabel);

        busyWidget = new QWidget(UploadDialog);
        busyWidget->setObjectName(QStringLiteral("busyWidget"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(24);
        sizePolicy1.setVerticalStretch(24);
        sizePolicy1.setHeightForWidth(busyWidget->sizePolicy().hasHeightForWidth());
        busyWidget->setSizePolicy(sizePolicy1);
        busyWidget->setMinimumSize(QSize(24, 24));

        horizontalLayout->addWidget(busyWidget);


        verticalLayout->addLayout(horizontalLayout);

        stackedWidget = new QStackedWidget(UploadDialog);
        stackedWidget->setObjectName(QStringLiteral("stackedWidget"));
        page_3 = new QWidget();
        page_3->setObjectName(QStringLiteral("page_3"));
        gridLayout_3 = new QGridLayout(page_3);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        verticalSpacer_2 = new QSpacerItem(205, 183, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 4, 1, 1, 1);

        password = new QLineEdit(page_3);
        password->setObjectName(QStringLiteral("password"));
        password->setEchoMode(QLineEdit::Password);

        gridLayout_3->addWidget(password, 2, 1, 1, 1);

        label_11 = new QLabel(page_3);
        label_11->setObjectName(QStringLiteral("label_11"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy2);
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_11, 2, 0, 1, 1);

        label_10 = new QLabel(page_3);
        label_10->setObjectName(QStringLiteral("label_10"));
        sizePolicy2.setHeightForWidth(label_10->sizePolicy().hasHeightForWidth());
        label_10->setSizePolicy(sizePolicy2);
        label_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_10, 1, 0, 1, 1);

        providerComboBox = new QComboBox(page_3);
        providerComboBox->setObjectName(QStringLiteral("providerComboBox"));

        gridLayout_3->addWidget(providerComboBox, 0, 1, 1, 1);

        username = new QLineEdit(page_3);
        username->setObjectName(QStringLiteral("username"));

        gridLayout_3->addWidget(username, 1, 1, 1, 1);

        label_9 = new QLabel(page_3);
        label_9->setObjectName(QStringLiteral("label_9"));
        sizePolicy2.setHeightForWidth(label_9->sizePolicy().hasHeightForWidth());
        label_9->setSizePolicy(sizePolicy2);
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_9, 0, 0, 1, 1);

        registerNewAccountLabel = new QLabel(page_3);
        registerNewAccountLabel->setObjectName(QStringLiteral("registerNewAccountLabel"));

        gridLayout_3->addWidget(registerNewAccountLabel, 3, 1, 1, 1, Qt::AlignRight);

        stackedWidget->addWidget(page_3);
        page_5 = new QWidget();
        page_5->setObjectName(QStringLiteral("page_5"));
        verticalLayout_4 = new QVBoxLayout(page_5);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        uploadFileLabel = new QLabel(page_5);
        uploadFileLabel->setObjectName(QStringLiteral("uploadFileLabel"));

        verticalLayout_4->addWidget(uploadFileLabel);

        uploadFileRequester = new KUrlRequester(page_5);
        uploadFileRequester->setObjectName(QStringLiteral("uploadFileRequester"));

        verticalLayout_4->addWidget(uploadFileRequester);

        radioNewUpload = new QRadioButton(page_5);
        radioNewUpload->setObjectName(QStringLiteral("radioNewUpload"));
        radioNewUpload->setChecked(true);

        verticalLayout_4->addWidget(radioNewUpload);

        radioUpdate = new QRadioButton(page_5);
        radioUpdate->setObjectName(QStringLiteral("radioUpdate"));
        radioUpdate->setEnabled(false);

        verticalLayout_4->addWidget(radioUpdate);

        userContentList = new QListWidget(page_5);
        userContentList->setObjectName(QStringLiteral("userContentList"));
        userContentList->setEnabled(false);

        verticalLayout_4->addWidget(userContentList);

        stackedWidget->addWidget(page_5);
        page = new QWidget();
        page->setObjectName(QStringLiteral("page"));
        gridLayout = new QGridLayout(page);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        mSummaryEdit = new KTextEdit(page);
        mSummaryEdit->setObjectName(QStringLiteral("mSummaryEdit"));

        gridLayout->addWidget(mSummaryEdit, 5, 2, 1, 2);

        mLicenseCombo = new KComboBox(page);
        mLicenseCombo->setObjectName(QStringLiteral("mLicenseCombo"));
        mLicenseCombo->setEditable(true);

        gridLayout->addWidget(mLicenseCombo, 4, 2, 1, 2);

        label_8 = new QLabel(page);
        label_8->setObjectName(QStringLiteral("label_8"));
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_8, 5, 0, 1, 2);

        priceLabel_2 = new QLabel(page);
        priceLabel_2->setObjectName(QStringLiteral("priceLabel_2"));
        priceLabel_2->setEnabled(true);
        priceLabel_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(priceLabel_2, 6, 1, 1, 1);

        label_5 = new QLabel(page);
        label_5->setObjectName(QStringLiteral("label_5"));
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 3, 0, 1, 2);

        label_6 = new QLabel(page);
        label_6->setObjectName(QStringLiteral("label_6"));
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 4, 0, 1, 2);

        label_12 = new QLabel(page);
        label_12->setObjectName(QStringLiteral("label_12"));

        gridLayout->addWidget(label_12, 0, 0, 1, 4);

        mVersionEdit = new QLineEdit(page);
        mVersionEdit->setObjectName(QStringLiteral("mVersionEdit"));

        gridLayout->addWidget(mVersionEdit, 3, 2, 1, 2);

        label_4 = new QLabel(page);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 1, 1, 1, 1);

        changelog = new KTextEdit(page);
        changelog->setObjectName(QStringLiteral("changelog"));

        gridLayout->addWidget(changelog, 6, 2, 1, 1);

        mCategoryLabel = new QLabel(page);
        mCategoryLabel->setObjectName(QStringLiteral("mCategoryLabel"));
        mCategoryLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(mCategoryLabel, 2, 0, 1, 2);

        mNameEdit = new QLineEdit(page);
        mNameEdit->setObjectName(QStringLiteral("mNameEdit"));

        gridLayout->addWidget(mNameEdit, 1, 2, 1, 2);

        mCategoryCombo = new KComboBox(page);
        mCategoryCombo->setObjectName(QStringLiteral("mCategoryCombo"));

        gridLayout->addWidget(mCategoryCombo, 2, 2, 1, 2);

        stackedWidget->addWidget(page);
        page_4 = new QWidget();
        page_4->setObjectName(QStringLiteral("page_4"));
        verticalLayout_2 = new QVBoxLayout(page_4);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        groupBox_2 = new QGroupBox(page_4);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setCheckable(false);
        gridLayout_5 = new QGridLayout(groupBox_2);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        changePreview1Button = new QPushButton(groupBox_2);
        changePreview1Button->setObjectName(QStringLiteral("changePreview1Button"));

        gridLayout_5->addWidget(changePreview1Button, 2, 0, 1, 1);

        changePreview3Button = new QPushButton(groupBox_2);
        changePreview3Button->setObjectName(QStringLiteral("changePreview3Button"));

        gridLayout_5->addWidget(changePreview3Button, 2, 3, 1, 1);

        changePreview2Button = new QPushButton(groupBox_2);
        changePreview2Button->setObjectName(QStringLiteral("changePreview2Button"));

        gridLayout_5->addWidget(changePreview2Button, 2, 2, 1, 1);

        previewImage1 = new QLabel(groupBox_2);
        previewImage1->setObjectName(QStringLiteral("previewImage1"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy3.setHorizontalStretch(96);
        sizePolicy3.setVerticalStretch(72);
        sizePolicy3.setHeightForWidth(previewImage1->sizePolicy().hasHeightForWidth());
        previewImage1->setSizePolicy(sizePolicy3);
        previewImage1->setMinimumSize(QSize(96, 82));
        previewImage1->setAlignment(Qt::AlignCenter);

        gridLayout_5->addWidget(previewImage1, 1, 0, 1, 1);

        previewImage2 = new QLabel(groupBox_2);
        previewImage2->setObjectName(QStringLiteral("previewImage2"));
        sizePolicy3.setHeightForWidth(previewImage2->sizePolicy().hasHeightForWidth());
        previewImage2->setSizePolicy(sizePolicy3);
        previewImage2->setMinimumSize(QSize(96, 82));
        previewImage2->setAlignment(Qt::AlignCenter);

        gridLayout_5->addWidget(previewImage2, 1, 2, 1, 1);

        previewImage3 = new QLabel(groupBox_2);
        previewImage3->setObjectName(QStringLiteral("previewImage3"));
        sizePolicy3.setHeightForWidth(previewImage3->sizePolicy().hasHeightForWidth());
        previewImage3->setSizePolicy(sizePolicy3);
        previewImage3->setMinimumSize(QSize(96, 82));
        previewImage3->setAlignment(Qt::AlignCenter);

        gridLayout_5->addWidget(previewImage3, 1, 3, 1, 1);


        verticalLayout_2->addWidget(groupBox_2);

        priceCheckBox = new QCheckBox(page_4);
        priceCheckBox->setObjectName(QStringLiteral("priceCheckBox"));

        verticalLayout_2->addWidget(priceCheckBox);

        priceGroupBox = new QGroupBox(page_4);
        priceGroupBox->setObjectName(QStringLiteral("priceGroupBox"));
        priceGroupBox->setEnabled(false);
        priceGroupBox->setCheckable(false);
        gridLayout_2 = new QGridLayout(priceGroupBox);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        priceLabel = new QLabel(priceGroupBox);
        priceLabel->setObjectName(QStringLiteral("priceLabel"));
        priceLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(priceLabel, 0, 0, 1, 1);

        priceSpinBox = new QDoubleSpinBox(priceGroupBox);
        priceSpinBox->setObjectName(QStringLiteral("priceSpinBox"));
        priceSpinBox->setSingleStep(0.01);
        priceSpinBox->setValue(1);

        gridLayout_2->addWidget(priceSpinBox, 0, 1, 1, 1);

        priceCurrency = new QLabel(priceGroupBox);
        priceCurrency->setObjectName(QStringLiteral("priceCurrency"));

        gridLayout_2->addWidget(priceCurrency, 0, 2, 1, 1);

        priceReasonLabel = new QLabel(priceGroupBox);
        priceReasonLabel->setObjectName(QStringLiteral("priceReasonLabel"));
        priceReasonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(priceReasonLabel, 1, 0, 1, 1);

        priceReasonLineEdit = new QLineEdit(priceGroupBox);
        priceReasonLineEdit->setObjectName(QStringLiteral("priceReasonLineEdit"));

        gridLayout_2->addWidget(priceReasonLineEdit, 1, 1, 1, 2);


        verticalLayout_2->addWidget(priceGroupBox);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);

        stackedWidget->addWidget(page_4);
        page_2 = new QWidget();
        page_2->setObjectName(QStringLiteral("page_2"));
        verticalLayout_3 = new QVBoxLayout(page_2);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        createContentImageLabel = new QLabel(page_2);
        createContentImageLabel->setObjectName(QStringLiteral("createContentImageLabel"));
        QSizePolicy sizePolicy4(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy4.setHorizontalStretch(22);
        sizePolicy4.setVerticalStretch(22);
        sizePolicy4.setHeightForWidth(createContentImageLabel->sizePolicy().hasHeightForWidth());
        createContentImageLabel->setSizePolicy(sizePolicy4);
        createContentImageLabel->setMinimumSize(QSize(22, 22));

        gridLayout_4->addWidget(createContentImageLabel, 2, 0, 1, 1);

        uploadContentImageLabel = new QLabel(page_2);
        uploadContentImageLabel->setObjectName(QStringLiteral("uploadContentImageLabel"));
        sizePolicy4.setHeightForWidth(uploadContentImageLabel->sizePolicy().hasHeightForWidth());
        uploadContentImageLabel->setSizePolicy(sizePolicy4);
        uploadContentImageLabel->setMinimumSize(QSize(22, 22));

        gridLayout_4->addWidget(uploadContentImageLabel, 3, 0, 1, 1);

        uploadPreview1ImageLabel = new QLabel(page_2);
        uploadPreview1ImageLabel->setObjectName(QStringLiteral("uploadPreview1ImageLabel"));
        sizePolicy4.setHeightForWidth(uploadPreview1ImageLabel->sizePolicy().hasHeightForWidth());
        uploadPreview1ImageLabel->setSizePolicy(sizePolicy4);
        uploadPreview1ImageLabel->setMinimumSize(QSize(22, 22));

        gridLayout_4->addWidget(uploadPreview1ImageLabel, 4, 0, 1, 1);

        fetchContentLinkImageLabel = new QLabel(page_2);
        fetchContentLinkImageLabel->setObjectName(QStringLiteral("fetchContentLinkImageLabel"));
        sizePolicy4.setHeightForWidth(fetchContentLinkImageLabel->sizePolicy().hasHeightForWidth());
        fetchContentLinkImageLabel->setSizePolicy(sizePolicy4);
        fetchContentLinkImageLabel->setMinimumSize(QSize(22, 22));
        fetchContentLinkImageLabel->setMaximumSize(QSize(22, 16777215));

        gridLayout_4->addWidget(fetchContentLinkImageLabel, 7, 0, 1, 1);

        contentWebsiteLinkLabel = new QLabel(page_2);
        contentWebsiteLinkLabel->setObjectName(QStringLiteral("contentWebsiteLinkLabel"));

        gridLayout_4->addWidget(contentWebsiteLinkLabel, 7, 1, 1, 1);

        creatingContentLabel = new QLabel(page_2);
        creatingContentLabel->setObjectName(QStringLiteral("creatingContentLabel"));
        sizePolicy.setHeightForWidth(creatingContentLabel->sizePolicy().hasHeightForWidth());
        creatingContentLabel->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(creatingContentLabel, 2, 1, 1, 1);

        creatingContentLabel_2 = new QLabel(page_2);
        creatingContentLabel_2->setObjectName(QStringLiteral("creatingContentLabel_2"));
        sizePolicy.setHeightForWidth(creatingContentLabel_2->sizePolicy().hasHeightForWidth());
        creatingContentLabel_2->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(creatingContentLabel_2, 3, 1, 1, 1);

        uploadPreview1Label = new QLabel(page_2);
        uploadPreview1Label->setObjectName(QStringLiteral("uploadPreview1Label"));
        sizePolicy.setHeightForWidth(uploadPreview1Label->sizePolicy().hasHeightForWidth());
        uploadPreview1Label->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(uploadPreview1Label, 4, 1, 1, 1);

        contentWebsiteLink = new QLabel(page_2);
        contentWebsiteLink->setObjectName(QStringLiteral("contentWebsiteLink"));
        contentWebsiteLink->setOpenExternalLinks(true);

        gridLayout_4->addWidget(contentWebsiteLink, 9, 1, 1, 1);

        verticalSpacer = new QSpacerItem(91, 199, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 11, 1, 1, 1);

        label_2 = new QLabel(page_2);
        label_2->setObjectName(QStringLiteral("label_2"));
        label_2->setWordWrap(true);

        gridLayout_4->addWidget(label_2, 10, 1, 1, 1);

        uploadPreview2Label = new QLabel(page_2);
        uploadPreview2Label->setObjectName(QStringLiteral("uploadPreview2Label"));
        sizePolicy.setHeightForWidth(uploadPreview2Label->sizePolicy().hasHeightForWidth());
        uploadPreview2Label->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(uploadPreview2Label, 5, 1, 1, 1);

        uploadPreview3Label = new QLabel(page_2);
        uploadPreview3Label->setObjectName(QStringLiteral("uploadPreview3Label"));
        sizePolicy.setHeightForWidth(uploadPreview3Label->sizePolicy().hasHeightForWidth());
        uploadPreview3Label->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(uploadPreview3Label, 6, 1, 1, 1);

        uploadPreview2ImageLabel = new QLabel(page_2);
        uploadPreview2ImageLabel->setObjectName(QStringLiteral("uploadPreview2ImageLabel"));
        sizePolicy4.setHeightForWidth(uploadPreview2ImageLabel->sizePolicy().hasHeightForWidth());
        uploadPreview2ImageLabel->setSizePolicy(sizePolicy4);
        uploadPreview2ImageLabel->setMinimumSize(QSize(22, 22));

        gridLayout_4->addWidget(uploadPreview2ImageLabel, 5, 0, 1, 1);

        uploadPreview3ImageLabel = new QLabel(page_2);
        uploadPreview3ImageLabel->setObjectName(QStringLiteral("uploadPreview3ImageLabel"));
        sizePolicy4.setHeightForWidth(uploadPreview3ImageLabel->sizePolicy().hasHeightForWidth());
        uploadPreview3ImageLabel->setSizePolicy(sizePolicy4);
        uploadPreview3ImageLabel->setMinimumSize(QSize(22, 22));

        gridLayout_4->addWidget(uploadPreview3ImageLabel, 6, 0, 1, 1);

        label = new QLabel(page_2);
        label->setObjectName(QStringLiteral("label"));
        label->setWordWrap(true);

        gridLayout_4->addWidget(label, 0, 0, 1, 2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        uploadButton = new QPushButton(page_2);
        uploadButton->setObjectName(QStringLiteral("uploadButton"));

        horizontalLayout_2->addWidget(uploadButton);


        gridLayout_4->addLayout(horizontalLayout_2, 1, 0, 1, 2);

        uploadProgressBar = new QProgressBar(page_2);
        uploadProgressBar->setObjectName(QStringLiteral("uploadProgressBar"));
        uploadProgressBar->setMaximum(1);
        uploadProgressBar->setValue(-1);

        gridLayout_4->addWidget(uploadProgressBar, 8, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_4);

        stackedWidget->addWidget(page_2);

        verticalLayout->addWidget(stackedWidget);

#ifndef UI_QT_NO_SHORTCUT
        label_8->setBuddy(mSummaryEdit);
        label_5->setBuddy(mVersionEdit);
        label_6->setBuddy(mLicenseCombo);
        label_4->setBuddy(mNameEdit);
        mCategoryLabel->setBuddy(mNameEdit);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(providerComboBox, username);
        QWidget::setTabOrder(username, password);
        QWidget::setTabOrder(password, uploadFileRequester);
        QWidget::setTabOrder(uploadFileRequester, radioNewUpload);
        QWidget::setTabOrder(radioNewUpload, radioUpdate);
        QWidget::setTabOrder(radioUpdate, userContentList);
        QWidget::setTabOrder(userContentList, mNameEdit);
        QWidget::setTabOrder(mNameEdit, mCategoryCombo);
        QWidget::setTabOrder(mCategoryCombo, mVersionEdit);
        QWidget::setTabOrder(mVersionEdit, mLicenseCombo);
        QWidget::setTabOrder(mLicenseCombo, mSummaryEdit);
        QWidget::setTabOrder(mSummaryEdit, changelog);
        QWidget::setTabOrder(changelog, priceCheckBox);
        QWidget::setTabOrder(priceCheckBox, priceSpinBox);
        QWidget::setTabOrder(priceSpinBox, priceReasonLineEdit);
        QWidget::setTabOrder(priceReasonLineEdit, uploadButton);

        retranslateUi(UploadDialog);

        stackedWidget->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(UploadDialog);
    } // setupUi

    void retranslateUi(QWidget *UploadDialog)
    {
        UploadDialog->setWindowTitle(tr2i18n("Share Hot New Stuff", Q_NULLPTR));
        busyLabel->setText(QString());
        label_11->setText(tr2i18n("Password:", Q_NULLPTR));
        label_10->setText(tr2i18n("Username:", Q_NULLPTR));
        label_9->setText(tr2i18n("Provider:", Q_NULLPTR));
        registerNewAccountLabel->setText(QString());
        uploadFileLabel->setText(tr2i18n("File to upload:", Q_NULLPTR));
        radioNewUpload->setText(tr2i18n("New Upload", Q_NULLPTR));
        radioUpdate->setText(tr2i18n("Update", Q_NULLPTR));
        mLicenseCombo->clear();
        mLicenseCombo->insertItems(0, QStringList()
         << tr2i18n("GPL", Q_NULLPTR)
         << tr2i18n("LGPL", Q_NULLPTR)
         << tr2i18n("BSD", Q_NULLPTR)
        );
        label_8->setText(tr2i18n("Description:", Q_NULLPTR));
        priceLabel_2->setText(tr2i18n("Changelog:", Q_NULLPTR));
        label_5->setText(tr2i18n("Version:", Q_NULLPTR));
        label_6->setText(tr2i18n("License:", Q_NULLPTR));
        label_12->setText(tr2i18n("Please fill out the information about your upload in English.", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        label_4->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        label_4->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        label_4->setText(tr2i18n("Title:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        mCategoryLabel->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        mCategoryLabel->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        mCategoryLabel->setText(tr2i18n("Category:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        mNameEdit->setToolTip(tr2i18n("Name of the file as it will appear on the website", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        mNameEdit->setWhatsThis(tr2i18n("This should clearly describe the file content. It can be the same text as the title of the kvtml file.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        groupBox_2->setTitle(tr2i18n("Preview Images", Q_NULLPTR));
        changePreview1Button->setText(tr2i18n("Select Preview...", Q_NULLPTR));
        changePreview3Button->setText(tr2i18n("Select Preview...", Q_NULLPTR));
        changePreview2Button->setText(tr2i18n("Select Preview...", Q_NULLPTR));
        previewImage1->setText(QString());
        previewImage2->setText(QString());
        previewImage3->setText(QString());
        priceCheckBox->setText(tr2i18n("Set a price for this item", Q_NULLPTR));
        priceGroupBox->setTitle(tr2i18n("Price", Q_NULLPTR));
        priceLabel->setText(tr2i18n("Price:", Q_NULLPTR));
        priceCurrency->setText(QString());
        priceReasonLabel->setText(tr2i18n("Reason for price:", Q_NULLPTR));
        createContentImageLabel->setText(QString());
        uploadContentImageLabel->setText(QString());
        uploadPreview1ImageLabel->setText(QString());
        fetchContentLinkImageLabel->setText(QString());
        contentWebsiteLinkLabel->setText(tr2i18n("Fetch content link from server", Q_NULLPTR));
        creatingContentLabel->setText(tr2i18n("Create content on server", Q_NULLPTR));
        creatingContentLabel_2->setText(tr2i18n("Upload content", Q_NULLPTR));
        uploadPreview1Label->setText(tr2i18n("Upload first preview", Q_NULLPTR));
        contentWebsiteLink->setText(QString());
        label_2->setText(tr2i18n("Note: You can edit, update and delete your content on the website.", Q_NULLPTR));
        uploadPreview2Label->setText(tr2i18n("Upload second preview", Q_NULLPTR));
        uploadPreview3Label->setText(tr2i18n("Upload third preview", Q_NULLPTR));
        uploadPreview2ImageLabel->setText(QString());
        uploadPreview3ImageLabel->setText(QString());
        label->setText(tr2i18n("I ensure that this content does not violate any existing copyright, law or trademark. I agree for my IP address to be logged. (Distributing content without the permission of the copyright holder is illegal.)", Q_NULLPTR));
        uploadButton->setText(tr2i18n("Start Upload", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class UploadDialog: public Ui_UploadDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UPLOADDIALOG_H

