/****************************************************************************
** Meta object code from reading C++ file 'uploaddialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knewstuff-5.43.0/src/uploaddialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'uploaddialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNS3__UploadDialog_t {
    QByteArrayData data[34];
    char stringdata0[643];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNS3__UploadDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNS3__UploadDialog_t qt_meta_stringdata_KNS3__UploadDialog = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KNS3::UploadDialog"
QT_MOC_LITERAL(1, 19, 6), // "accept"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 11), // "_k_nextPage"
QT_MOC_LITERAL(4, 39, 11), // "_k_backPage"
QT_MOC_LITERAL(5, 51, 13), // "_k_updatePage"
QT_MOC_LITERAL(6, 65, 18), // "_k_providerChanged"
QT_MOC_LITERAL(7, 84, 27), // "_k_checkCredentialsFinished"
QT_MOC_LITERAL(8, 112, 29), // "_k_contentByCurrentUserLoaded"
QT_MOC_LITERAL(9, 142, 21), // "Attica::Content::List"
QT_MOC_LITERAL(10, 164, 18), // "_k_providersLoaded"
QT_MOC_LITERAL(11, 183, 19), // "_k_categoriesLoaded"
QT_MOC_LITERAL(12, 203, 22), // "Attica::Category::List"
QT_MOC_LITERAL(13, 226, 17), // "_k_licensesLoaded"
QT_MOC_LITERAL(14, 244, 21), // "Attica::License::List"
QT_MOC_LITERAL(15, 266, 17), // "_k_currencyLoaded"
QT_MOC_LITERAL(16, 284, 16), // "_k_previewLoaded"
QT_MOC_LITERAL(17, 301, 17), // "_k_changePreview1"
QT_MOC_LITERAL(18, 319, 17), // "_k_changePreview2"
QT_MOC_LITERAL(19, 337, 17), // "_k_changePreview3"
QT_MOC_LITERAL(20, 355, 15), // "_k_priceToggled"
QT_MOC_LITERAL(21, 371, 24), // "_k_updateContentsToggled"
QT_MOC_LITERAL(22, 396, 6), // "update"
QT_MOC_LITERAL(23, 403, 14), // "_k_startUpload"
QT_MOC_LITERAL(24, 418, 15), // "_k_contentAdded"
QT_MOC_LITERAL(25, 434, 16), // "Attica::BaseJob*"
QT_MOC_LITERAL(26, 451, 21), // "_k_fileUploadFinished"
QT_MOC_LITERAL(27, 473, 25), // "_k_preview1UploadFinished"
QT_MOC_LITERAL(28, 499, 25), // "_k_preview2UploadFinished"
QT_MOC_LITERAL(29, 525, 25), // "_k_preview3UploadFinished"
QT_MOC_LITERAL(30, 551, 24), // "_k_updatedContentFetched"
QT_MOC_LITERAL(31, 576, 15), // "Attica::Content"
QT_MOC_LITERAL(32, 592, 20), // "_k_detailsLinkLoaded"
QT_MOC_LITERAL(33, 613, 29) // "_k_openRegisterAccountWebpage"

    },
    "KNS3::UploadDialog\0accept\0\0_k_nextPage\0"
    "_k_backPage\0_k_updatePage\0_k_providerChanged\0"
    "_k_checkCredentialsFinished\0"
    "_k_contentByCurrentUserLoaded\0"
    "Attica::Content::List\0_k_providersLoaded\0"
    "_k_categoriesLoaded\0Attica::Category::List\0"
    "_k_licensesLoaded\0Attica::License::List\0"
    "_k_currencyLoaded\0_k_previewLoaded\0"
    "_k_changePreview1\0_k_changePreview2\0"
    "_k_changePreview3\0_k_priceToggled\0"
    "_k_updateContentsToggled\0update\0"
    "_k_startUpload\0_k_contentAdded\0"
    "Attica::BaseJob*\0_k_fileUploadFinished\0"
    "_k_preview1UploadFinished\0"
    "_k_preview2UploadFinished\0"
    "_k_preview3UploadFinished\0"
    "_k_updatedContentFetched\0Attica::Content\0"
    "_k_detailsLinkLoaded\0_k_openRegisterAccountWebpage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNS3__UploadDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      26,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  144,    2, 0x0a /* Public */,
       3,    0,  145,    2, 0x08 /* Private */,
       4,    0,  146,    2, 0x08 /* Private */,
       5,    0,  147,    2, 0x08 /* Private */,
       6,    1,  148,    2, 0x08 /* Private */,
       7,    1,  151,    2, 0x08 /* Private */,
       8,    1,  154,    2, 0x08 /* Private */,
      10,    1,  157,    2, 0x08 /* Private */,
      11,    1,  160,    2, 0x08 /* Private */,
      13,    1,  163,    2, 0x08 /* Private */,
      15,    1,  166,    2, 0x08 /* Private */,
      16,    2,  169,    2, 0x08 /* Private */,
      17,    0,  174,    2, 0x08 /* Private */,
      18,    0,  175,    2, 0x08 /* Private */,
      19,    0,  176,    2, 0x08 /* Private */,
      20,    1,  177,    2, 0x08 /* Private */,
      21,    1,  180,    2, 0x08 /* Private */,
      23,    0,  183,    2, 0x08 /* Private */,
      24,    1,  184,    2, 0x08 /* Private */,
      26,    1,  187,    2, 0x08 /* Private */,
      27,    1,  190,    2, 0x08 /* Private */,
      28,    1,  193,    2, 0x08 /* Private */,
      29,    1,  196,    2, 0x08 /* Private */,
      30,    1,  199,    2, 0x08 /* Private */,
      32,    1,  202,    2, 0x08 /* Private */,
      33,    1,  205,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::QStringList,    2,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QImage,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 31,    2,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void KNS3::UploadDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        UploadDialog *_t = static_cast<UploadDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->accept(); break;
        case 1: _t->d->_k_nextPage(); break;
        case 2: _t->d->_k_backPage(); break;
        case 3: _t->d->_k_updatePage(); break;
        case 4: _t->d->_k_providerChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->d->_k_checkCredentialsFinished((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->d->_k_contentByCurrentUserLoaded((*reinterpret_cast< Attica::Content::List(*)>(_a[1]))); break;
        case 7: _t->d->_k_providersLoaded((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        case 8: _t->d->_k_categoriesLoaded((*reinterpret_cast< Attica::Category::List(*)>(_a[1]))); break;
        case 9: _t->d->_k_licensesLoaded((*reinterpret_cast< Attica::License::List(*)>(_a[1]))); break;
        case 10: _t->d->_k_currencyLoaded((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 11: _t->d->_k_previewLoaded((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QImage(*)>(_a[2]))); break;
        case 12: _t->d->_k_changePreview1(); break;
        case 13: _t->d->_k_changePreview2(); break;
        case 14: _t->d->_k_changePreview3(); break;
        case 15: _t->d->_k_priceToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->d->_k_updateContentsToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->d->_k_startUpload(); break;
        case 18: _t->d->_k_contentAdded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 19: _t->d->_k_fileUploadFinished((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 20: _t->d->_k_preview1UploadFinished((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 21: _t->d->_k_preview2UploadFinished((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 22: _t->d->_k_preview3UploadFinished((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 23: _t->d->_k_updatedContentFetched((*reinterpret_cast< Attica::Content(*)>(_a[1]))); break;
        case 24: _t->d->_k_detailsLinkLoaded((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 25: _t->d->_k_openRegisterAccountWebpage((*reinterpret_cast< QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KNS3::UploadDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KNS3__UploadDialog.data,
      qt_meta_data_KNS3__UploadDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNS3::UploadDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNS3::UploadDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNS3__UploadDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KNS3::UploadDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
