/****************************************************************************
** Meta object code from reading C++ file 'atticahelper_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/upload/atticahelper_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'atticahelper_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNSCore__AtticaHelper_t {
    QByteArrayData data[26];
    char stringdata0[384];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNSCore__AtticaHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNSCore__AtticaHelper_t qt_meta_stringdata_KNSCore__AtticaHelper = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KNSCore::AtticaHelper"
QT_MOC_LITERAL(1, 22, 12), // "loginChecked"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 15), // "providersLoaded"
QT_MOC_LITERAL(4, 52, 16), // "categoriesLoaded"
QT_MOC_LITERAL(5, 69, 22), // "Attica::Category::List"
QT_MOC_LITERAL(6, 92, 26), // "contentByCurrentUserLoaded"
QT_MOC_LITERAL(7, 119, 21), // "Attica::Content::List"
QT_MOC_LITERAL(8, 141, 14), // "licensesLoaded"
QT_MOC_LITERAL(9, 156, 21), // "Attica::License::List"
QT_MOC_LITERAL(10, 178, 17), // "detailsLinkLoaded"
QT_MOC_LITERAL(11, 196, 13), // "contentLoaded"
QT_MOC_LITERAL(12, 210, 15), // "Attica::Content"
QT_MOC_LITERAL(13, 226, 14), // "currencyLoaded"
QT_MOC_LITERAL(14, 241, 13), // "previewLoaded"
QT_MOC_LITERAL(15, 255, 5), // "index"
QT_MOC_LITERAL(16, 261, 5), // "image"
QT_MOC_LITERAL(17, 267, 18), // "checkLoginFinished"
QT_MOC_LITERAL(18, 286, 16), // "Attica::BaseJob*"
QT_MOC_LITERAL(19, 303, 7), // "baseJob"
QT_MOC_LITERAL(20, 311, 22), // "defaultProvidersLoaded"
QT_MOC_LITERAL(21, 334, 15), // "slotPreviewData"
QT_MOC_LITERAL(22, 350, 5), // "KJob*"
QT_MOC_LITERAL(23, 356, 3), // "job"
QT_MOC_LITERAL(24, 360, 3), // "buf"
QT_MOC_LITERAL(25, 364, 19) // "slotPreviewDownload"

    },
    "KNSCore::AtticaHelper\0loginChecked\0\0"
    "providersLoaded\0categoriesLoaded\0"
    "Attica::Category::List\0"
    "contentByCurrentUserLoaded\0"
    "Attica::Content::List\0licensesLoaded\0"
    "Attica::License::List\0detailsLinkLoaded\0"
    "contentLoaded\0Attica::Content\0"
    "currencyLoaded\0previewLoaded\0index\0"
    "image\0checkLoginFinished\0Attica::BaseJob*\0"
    "baseJob\0defaultProvidersLoaded\0"
    "slotPreviewData\0KJob*\0job\0buf\0"
    "slotPreviewDownload"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNSCore__AtticaHelper[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  109,    2, 0x06 /* Public */,
       3,    1,  112,    2, 0x06 /* Public */,
       4,    1,  115,    2, 0x06 /* Public */,
       6,    1,  118,    2, 0x06 /* Public */,
       8,    1,  121,    2, 0x06 /* Public */,
      10,    1,  124,    2, 0x06 /* Public */,
      11,    1,  127,    2, 0x06 /* Public */,
      13,    1,  130,    2, 0x06 /* Public */,
      14,    2,  133,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      17,    1,  138,    2, 0x08 /* Private */,
      20,    0,  141,    2, 0x08 /* Private */,
       4,    1,  142,    2, 0x08 /* Private */,
       6,    1,  145,    2, 0x08 /* Private */,
       8,    1,  148,    2, 0x08 /* Private */,
      10,    1,  151,    2, 0x08 /* Private */,
      11,    1,  154,    2, 0x08 /* Private */,
      13,    1,  157,    2, 0x08 /* Private */,
      21,    2,  160,    2, 0x08 /* Private */,
      25,    1,  165,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QStringList,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 7,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QImage,   15,   16,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 22, QMetaType::QByteArray,   23,   24,
    QMetaType::Void, 0x80000000 | 22,   23,

       0        // eod
};

void KNSCore::AtticaHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AtticaHelper *_t = static_cast<AtticaHelper *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->loginChecked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->providersLoaded((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 2: _t->categoriesLoaded((*reinterpret_cast< Attica::Category::List(*)>(_a[1]))); break;
        case 3: _t->contentByCurrentUserLoaded((*reinterpret_cast< const Attica::Content::List(*)>(_a[1]))); break;
        case 4: _t->licensesLoaded((*reinterpret_cast< const Attica::License::List(*)>(_a[1]))); break;
        case 5: _t->detailsLinkLoaded((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 6: _t->contentLoaded((*reinterpret_cast< const Attica::Content(*)>(_a[1]))); break;
        case 7: _t->currencyLoaded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->previewLoaded((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QImage(*)>(_a[2]))); break;
        case 9: _t->checkLoginFinished((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 10: _t->defaultProvidersLoaded(); break;
        case 11: _t->categoriesLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 12: _t->contentByCurrentUserLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 13: _t->licensesLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 14: _t->detailsLinkLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 15: _t->contentLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 16: _t->currencyLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 17: _t->slotPreviewData((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 18: _t->slotPreviewDownload((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (AtticaHelper::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::loginChecked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::providersLoaded)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(Attica::Category::List );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::categoriesLoaded)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(const Attica::Content::List & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::contentByCurrentUserLoaded)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(const Attica::License::List & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::licensesLoaded)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::detailsLinkLoaded)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(const Attica::Content & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::contentLoaded)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::currencyLoaded)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (AtticaHelper::*_t)(int , const QImage & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AtticaHelper::previewLoaded)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject KNSCore::AtticaHelper::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KNSCore__AtticaHelper.data,
      qt_meta_data_KNSCore__AtticaHelper,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNSCore::AtticaHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSCore::AtticaHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNSCore__AtticaHelper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNSCore::AtticaHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void KNSCore::AtticaHelper::loginChecked(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KNSCore::AtticaHelper::providersLoaded(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KNSCore::AtticaHelper::categoriesLoaded(Attica::Category::List _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KNSCore::AtticaHelper::contentByCurrentUserLoaded(const Attica::Content::List & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KNSCore::AtticaHelper::licensesLoaded(const Attica::License::List & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KNSCore::AtticaHelper::detailsLinkLoaded(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KNSCore::AtticaHelper::contentLoaded(const Attica::Content & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KNSCore::AtticaHelper::currencyLoaded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KNSCore::AtticaHelper::previewLoaded(int _t1, const QImage & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
