/****************************************************************************
** Meta object code from reading C++ file 'installation.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/core/installation.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'installation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNSCore__Installation_t {
    QByteArrayData data[21];
    char stringdata0[310];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNSCore__Installation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNSCore__Installation_t qt_meta_stringdata_KNSCore__Installation = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KNSCore::Installation"
QT_MOC_LITERAL(1, 22, 18), // "signalEntryChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 22), // "KNSCore::EntryInternal"
QT_MOC_LITERAL(4, 65, 5), // "entry"
QT_MOC_LITERAL(5, 71, 26), // "signalInstallationFinished"
QT_MOC_LITERAL(6, 98, 24), // "signalInstallationFailed"
QT_MOC_LITERAL(7, 123, 7), // "message"
QT_MOC_LITERAL(8, 131, 19), // "signalPayloadLoaded"
QT_MOC_LITERAL(9, 151, 7), // "payload"
QT_MOC_LITERAL(10, 159, 17), // "signalInformation"
QT_MOC_LITERAL(11, 177, 11), // "signalError"
QT_MOC_LITERAL(12, 189, 15), // "downloadPayload"
QT_MOC_LITERAL(13, 205, 7), // "install"
QT_MOC_LITERAL(14, 213, 9), // "uninstall"
QT_MOC_LITERAL(15, 223, 28), // "slotInstallationVerification"
QT_MOC_LITERAL(16, 252, 6), // "result"
QT_MOC_LITERAL(17, 259, 17), // "slotPayloadResult"
QT_MOC_LITERAL(18, 277, 5), // "KJob*"
QT_MOC_LITERAL(19, 283, 3), // "job"
QT_MOC_LITERAL(20, 287, 22) // "targetInstallationPath"

    },
    "KNSCore::Installation\0signalEntryChanged\0"
    "\0KNSCore::EntryInternal\0entry\0"
    "signalInstallationFinished\0"
    "signalInstallationFailed\0message\0"
    "signalPayloadLoaded\0payload\0"
    "signalInformation\0signalError\0"
    "downloadPayload\0install\0uninstall\0"
    "slotInstallationVerification\0result\0"
    "slotPayloadResult\0KJob*\0job\0"
    "targetInstallationPath"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNSCore__Installation[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       5,    0,   77,    2, 0x06 /* Public */,
       6,    1,   78,    2, 0x06 /* Public */,
       8,    1,   81,    2, 0x06 /* Public */,
      10,    1,   84,    2, 0x06 /* Public */,
      11,    1,   87,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,   90,    2, 0x0a /* Public */,
      13,    1,   93,    2, 0x0a /* Public */,
      14,    1,   96,    2, 0x0a /* Public */,
      15,    1,   99,    2, 0x0a /* Public */,
      17,    1,  102,    2, 0x0a /* Public */,
      20,    0,  105,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QUrl,    9,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,   16,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::QString,

       0        // eod
};

void KNSCore::Installation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Installation *_t = static_cast<Installation *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalEntryChanged((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 1: _t->signalInstallationFinished(); break;
        case 2: _t->signalInstallationFailed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->signalPayloadLoaded((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 4: _t->signalInformation((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->signalError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->downloadPayload((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 7: _t->install((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 8: _t->uninstall((*reinterpret_cast< KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 9: _t->slotInstallationVerification((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->slotPayloadResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 11: { QString _r = _t->targetInstallationPath();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Installation::*_t)(const KNSCore::EntryInternal & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Installation::signalEntryChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Installation::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Installation::signalInstallationFinished)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Installation::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Installation::signalInstallationFailed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Installation::*_t)(QUrl );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Installation::signalPayloadLoaded)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Installation::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Installation::signalInformation)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Installation::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Installation::signalError)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject KNSCore::Installation::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KNSCore__Installation.data,
      qt_meta_data_KNSCore__Installation,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNSCore::Installation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSCore::Installation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNSCore__Installation.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNSCore::Installation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KNSCore::Installation::signalEntryChanged(const KNSCore::EntryInternal & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KNSCore::Installation::signalInstallationFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KNSCore::Installation::signalInstallationFailed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KNSCore::Installation::signalPayloadLoaded(QUrl _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KNSCore::Installation::signalInformation(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< KNSCore::Installation *>(this), &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KNSCore::Installation::signalError(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< KNSCore::Installation *>(this), &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
