/****************************************************************************
** Meta object code from reading C++ file 'itemsviewbasedelegate_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knewstuff-5.43.0/src/ui/itemsviewbasedelegate_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemsviewbasedelegate_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNS3__ItemsViewBaseDelegate_t {
    QByteArrayData data[17];
    char stringdata0[217];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNS3__ItemsViewBaseDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNS3__ItemsViewBaseDelegate_t qt_meta_stringdata_KNS3__ItemsViewBaseDelegate = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KNS3::ItemsViewBaseDelegate"
QT_MOC_LITERAL(1, 28, 17), // "signalShowDetails"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 22), // "KNSCore::EntryInternal"
QT_MOC_LITERAL(4, 70, 5), // "entry"
QT_MOC_LITERAL(5, 76, 11), // "eventFilter"
QT_MOC_LITERAL(6, 88, 7), // "watched"
QT_MOC_LITERAL(7, 96, 7), // "QEvent*"
QT_MOC_LITERAL(8, 104, 5), // "event"
QT_MOC_LITERAL(9, 110, 18), // "slotInstallClicked"
QT_MOC_LITERAL(10, 129, 26), // "slotInstallActionTriggered"
QT_MOC_LITERAL(11, 156, 8), // "QAction*"
QT_MOC_LITERAL(12, 165, 6), // "action"
QT_MOC_LITERAL(13, 172, 15), // "slotLinkClicked"
QT_MOC_LITERAL(14, 188, 3), // "url"
QT_MOC_LITERAL(15, 192, 18), // "slotDetailsClicked"
QT_MOC_LITERAL(16, 211, 5) // "index"

    },
    "KNS3::ItemsViewBaseDelegate\0"
    "signalShowDetails\0\0KNSCore::EntryInternal\0"
    "entry\0eventFilter\0watched\0QEvent*\0"
    "event\0slotInstallClicked\0"
    "slotInstallActionTriggered\0QAction*\0"
    "action\0slotLinkClicked\0url\0"
    "slotDetailsClicked\0index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNS3__ItemsViewBaseDelegate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    2,   52,    2, 0x09 /* Protected */,
       9,    0,   57,    2, 0x09 /* Protected */,
      10,    1,   58,    2, 0x09 /* Protected */,
      13,    1,   61,    2, 0x09 /* Protected */,
      15,    1,   64,    2, 0x09 /* Protected */,
      15,    0,   67,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 7,    6,    8,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QModelIndex,   16,
    QMetaType::Void,

       0        // eod
};

void KNS3::ItemsViewBaseDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ItemsViewBaseDelegate *_t = static_cast<ItemsViewBaseDelegate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalShowDetails((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 1: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->slotInstallClicked(); break;
        case 3: _t->slotInstallActionTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 4: _t->slotLinkClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotDetailsClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 6: _t->slotDetailsClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ItemsViewBaseDelegate::*_t)(const KNSCore::EntryInternal & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ItemsViewBaseDelegate::signalShowDetails)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KNS3::ItemsViewBaseDelegate::staticMetaObject = {
    { &KWidgetItemDelegate::staticMetaObject, qt_meta_stringdata_KNS3__ItemsViewBaseDelegate.data,
      qt_meta_data_KNS3__ItemsViewBaseDelegate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNS3::ItemsViewBaseDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNS3::ItemsViewBaseDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNS3__ItemsViewBaseDelegate.stringdata0))
        return static_cast<void*>(this);
    return KWidgetItemDelegate::qt_metacast(_clname);
}

int KNS3::ItemsViewBaseDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KWidgetItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KNS3::ItemsViewBaseDelegate::signalShowDetails(const KNSCore::EntryInternal & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
