/****************************************************************************
** Meta object code from reading C++ file 'downloadwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knewstuff-5.43.0/src/downloadwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'downloadwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNS3__DownloadWidget_t {
    QByteArrayData data[30];
    char stringdata0[447];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNS3__DownloadWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNS3__DownloadWidget_t qt_meta_stringdata_KNS3__DownloadWidget = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KNS3::DownloadWidget"
QT_MOC_LITERAL(1, 21, 20), // "slotListViewListMode"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 20), // "slotListViewIconMode"
QT_MOC_LITERAL(4, 64, 19), // "slotProvidersLoaded"
QT_MOC_LITERAL(5, 84, 17), // "slotEntriesLoaded"
QT_MOC_LITERAL(6, 102, 28), // "KNSCore::EntryInternal::List"
QT_MOC_LITERAL(7, 131, 7), // "entries"
QT_MOC_LITERAL(8, 139, 16), // "slotEntryChanged"
QT_MOC_LITERAL(9, 156, 22), // "KNSCore::EntryInternal"
QT_MOC_LITERAL(10, 179, 5), // "entry"
QT_MOC_LITERAL(11, 185, 15), // "slotShowDetails"
QT_MOC_LITERAL(12, 201, 16), // "slotShowOverview"
QT_MOC_LITERAL(13, 218, 17), // "slotPayloadFailed"
QT_MOC_LITERAL(14, 236, 17), // "slotPayloadLoaded"
QT_MOC_LITERAL(15, 254, 3), // "url"
QT_MOC_LITERAL(16, 258, 16), // "slotResetMessage"
QT_MOC_LITERAL(17, 275, 18), // "slotNetworkTimeout"
QT_MOC_LITERAL(18, 294, 14), // "sortingChanged"
QT_MOC_LITERAL(19, 309, 21), // "slotSearchTextChanged"
QT_MOC_LITERAL(20, 331, 16), // "slotUpdateSearch"
QT_MOC_LITERAL(21, 348, 19), // "slotCategoryChanged"
QT_MOC_LITERAL(22, 368, 8), // "slotInfo"
QT_MOC_LITERAL(23, 377, 8), // "provider"
QT_MOC_LITERAL(24, 386, 6), // "server"
QT_MOC_LITERAL(25, 393, 7), // "version"
QT_MOC_LITERAL(26, 401, 9), // "slotError"
QT_MOC_LITERAL(27, 411, 7), // "message"
QT_MOC_LITERAL(28, 419, 21), // "scrollbarValueChanged"
QT_MOC_LITERAL(29, 441, 5) // "value"

    },
    "KNS3::DownloadWidget\0slotListViewListMode\0"
    "\0slotListViewIconMode\0slotProvidersLoaded\0"
    "slotEntriesLoaded\0KNSCore::EntryInternal::List\0"
    "entries\0slotEntryChanged\0"
    "KNSCore::EntryInternal\0entry\0"
    "slotShowDetails\0slotShowOverview\0"
    "slotPayloadFailed\0slotPayloadLoaded\0"
    "url\0slotResetMessage\0slotNetworkTimeout\0"
    "sortingChanged\0slotSearchTextChanged\0"
    "slotUpdateSearch\0slotCategoryChanged\0"
    "slotInfo\0provider\0server\0version\0"
    "slotError\0message\0scrollbarValueChanged\0"
    "value"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNS3__DownloadWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x08 /* Private */,
       3,    0,  105,    2, 0x08 /* Private */,
       4,    0,  106,    2, 0x08 /* Private */,
       5,    1,  107,    2, 0x08 /* Private */,
       8,    1,  110,    2, 0x08 /* Private */,
      11,    1,  113,    2, 0x08 /* Private */,
      12,    0,  116,    2, 0x08 /* Private */,
      13,    1,  117,    2, 0x08 /* Private */,
      14,    1,  120,    2, 0x08 /* Private */,
      16,    0,  123,    2, 0x08 /* Private */,
      17,    0,  124,    2, 0x08 /* Private */,
      18,    0,  125,    2, 0x08 /* Private */,
      19,    0,  126,    2, 0x08 /* Private */,
      20,    0,  127,    2, 0x08 /* Private */,
      21,    1,  128,    2, 0x08 /* Private */,
      22,    3,  131,    2, 0x08 /* Private */,
      26,    1,  138,    2, 0x08 /* Private */,
      28,    1,  141,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QUrl,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   23,   24,   25,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::Int,   29,

       0        // eod
};

void KNS3::DownloadWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DownloadWidget *_t = static_cast<DownloadWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->d->slotListViewListMode(); break;
        case 1: _t->d->slotListViewIconMode(); break;
        case 2: _t->d->slotProvidersLoaded(); break;
        case 3: _t->d->slotEntriesLoaded((*reinterpret_cast< const KNSCore::EntryInternal::List(*)>(_a[1]))); break;
        case 4: _t->d->slotEntryChanged((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 5: _t->d->slotShowDetails((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 6: _t->d->slotShowOverview(); break;
        case 7: _t->d->slotPayloadFailed((*reinterpret_cast< const KNSCore::EntryInternal(*)>(_a[1]))); break;
        case 8: _t->d->slotPayloadLoaded((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 9: _t->d->slotResetMessage(); break;
        case 10: _t->d->slotNetworkTimeout(); break;
        case 11: _t->d->sortingChanged(); break;
        case 12: _t->d->slotSearchTextChanged(); break;
        case 13: _t->d->slotUpdateSearch(); break;
        case 14: _t->d->slotCategoryChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->d->slotInfo((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 16: _t->d->slotError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->d->scrollbarValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KNS3::DownloadWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KNS3__DownloadWidget.data,
      qt_meta_data_KNS3__DownloadWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNS3::DownloadWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNS3::DownloadWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNS3__DownloadWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KNS3::DownloadWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
