#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'kmoretoolsconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KMORETOOLSCONFIGWIDGET_H
#define UI_KMORETOOLSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_KMoreToolsConfigWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *gbMainSection;
    QVBoxLayout *verticalLayout_2;
    QListWidget *listMainSection;
    QWidget *widget;
    QToolButton *buttonMoveDown;
    QToolButton *buttonMoveUp;
    QToolButton *buttonMoveToMain;
    QToolButton *buttonMoveToMore;
    QPushButton *buttonReset;
    QGroupBox *gbMoreSection;
    QVBoxLayout *verticalLayout_3;
    QListWidget *listMoreSection;
    QSpacerItem *horizontalSpacer_2;
    QFrame *frameNotInstalledTools;
    QVBoxLayout *verticalLayout_4;
    QLabel *label;
    QPushButton *buttonNotInstalledTools;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *KMoreToolsConfigWidget)
    {
        if (KMoreToolsConfigWidget->objectName().isEmpty())
            KMoreToolsConfigWidget->setObjectName(QStringLiteral("KMoreToolsConfigWidget"));
        KMoreToolsConfigWidget->resize(1001, 452);
        gridLayout = new QGridLayout(KMoreToolsConfigWidget);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        gbMainSection = new QGroupBox(KMoreToolsConfigWidget);
        gbMainSection->setObjectName(QStringLiteral("gbMainSection"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gbMainSection->sizePolicy().hasHeightForWidth());
        gbMainSection->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(gbMainSection);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        listMainSection = new QListWidget(gbMainSection);
        listMainSection->setObjectName(QStringLiteral("listMainSection"));

        verticalLayout_2->addWidget(listMainSection);


        horizontalLayout_2->addWidget(gbMainSection);

        widget = new QWidget(KMoreToolsConfigWidget);
        widget->setObjectName(QStringLiteral("widget"));
        sizePolicy.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy);
        widget->setMinimumSize(QSize(170, 325));
        buttonMoveDown = new QToolButton(widget);
        buttonMoveDown->setObjectName(QStringLiteral("buttonMoveDown"));
        buttonMoveDown->setGeometry(QRect(40, 190, 81, 41));
        QIcon icon;
        QString iconThemeName = QStringLiteral("arrow-down");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        buttonMoveDown->setIcon(icon);
        buttonMoveDown->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        buttonMoveUp = new QToolButton(widget);
        buttonMoveUp->setObjectName(QStringLiteral("buttonMoveUp"));
        buttonMoveUp->setGeometry(QRect(40, 140, 81, 41));
        QIcon icon1;
        iconThemeName = QStringLiteral("arrow-up");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        buttonMoveUp->setIcon(icon1);
        buttonMoveUp->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        buttonMoveToMain = new QToolButton(widget);
        buttonMoveToMain->setObjectName(QStringLiteral("buttonMoveToMain"));
        buttonMoveToMain->setGeometry(QRect(10, 90, 147, 41));
        QIcon icon2;
        iconThemeName = QStringLiteral("arrow-left");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        buttonMoveToMain->setIcon(icon2);
        buttonMoveToMain->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        buttonMoveToMore = new QToolButton(widget);
        buttonMoveToMore->setObjectName(QStringLiteral("buttonMoveToMore"));
        buttonMoveToMore->setGeometry(QRect(10, 40, 148, 41));
        QIcon icon3;
        iconThemeName = QStringLiteral("arrow-right");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        buttonMoveToMore->setIcon(icon3);
        buttonMoveToMore->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        buttonReset = new QPushButton(widget);
        buttonReset->setObjectName(QStringLiteral("buttonReset"));
        buttonReset->setGeometry(QRect(40, 280, 80, 21));
        QIcon icon4;
        iconThemeName = QStringLiteral("document-revert");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        buttonReset->setIcon(icon4);

        horizontalLayout_2->addWidget(widget);

        gbMoreSection = new QGroupBox(KMoreToolsConfigWidget);
        gbMoreSection->setObjectName(QStringLiteral("gbMoreSection"));
        sizePolicy.setHeightForWidth(gbMoreSection->sizePolicy().hasHeightForWidth());
        gbMoreSection->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(gbMoreSection);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        listMoreSection = new QListWidget(gbMoreSection);
        listMoreSection->setObjectName(QStringLiteral("listMoreSection"));

        verticalLayout_3->addWidget(listMoreSection);


        horizontalLayout_2->addWidget(gbMoreSection);

        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        frameNotInstalledTools = new QFrame(KMoreToolsConfigWidget);
        frameNotInstalledTools->setObjectName(QStringLiteral("frameNotInstalledTools"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frameNotInstalledTools->sizePolicy().hasHeightForWidth());
        frameNotInstalledTools->setSizePolicy(sizePolicy1);
        frameNotInstalledTools->setMinimumSize(QSize(100, 0));
        frameNotInstalledTools->setFrameShape(QFrame::NoFrame);
        frameNotInstalledTools->setFrameShadow(QFrame::Plain);
        frameNotInstalledTools->setLineWidth(0);
        verticalLayout_4 = new QVBoxLayout(frameNotInstalledTools);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        label = new QLabel(frameNotInstalledTools);
        label->setObjectName(QStringLiteral("label"));
        label->setWordWrap(true);

        verticalLayout_4->addWidget(label);

        buttonNotInstalledTools = new QPushButton(frameNotInstalledTools);
        buttonNotInstalledTools->setObjectName(QStringLiteral("buttonNotInstalledTools"));

        verticalLayout_4->addWidget(buttonNotInstalledTools);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);


        horizontalLayout_2->addWidget(frameNotInstalledTools);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);


        retranslateUi(KMoreToolsConfigWidget);

        QMetaObject::connectSlotsByName(KMoreToolsConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *KMoreToolsConfigWidget)
    {
        gbMainSection->setTitle(tr2i18n("Main section", Q_NULLPTR));
        buttonMoveDown->setText(tr2i18n("Move down", Q_NULLPTR));
        buttonMoveUp->setText(tr2i18n("Move up", Q_NULLPTR));
        buttonMoveToMain->setText(tr2i18n("Move to Main section", Q_NULLPTR));
        buttonMoveToMore->setText(tr2i18n("Move to More section", Q_NULLPTR));
        buttonReset->setText(tr2i18n("Reset", Q_NULLPTR));
        gbMoreSection->setTitle(tr2i18n("More section", Q_NULLPTR));
        label->setText(tr2i18n("For this menu there are some more tools suggested which are currently not installed:", Q_NULLPTR));
        buttonNotInstalledTools->setText(tr2i18n("More tools...", Q_NULLPTR));
        Q_UNUSED(KMoreToolsConfigWidget);
    } // retranslateUi

};

namespace Ui {
    class KMoreToolsConfigWidget: public Ui_KMoreToolsConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KMORETOOLSCONFIGWIDGET_H

