/****************************************************************************
** Meta object code from reading C++ file 'atticaprovider_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/knewstuff-5.43.0/src/attica/atticaprovider_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'atticaprovider_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNSCore__AtticaProvider_t {
    QByteArrayData data[16];
    char stringdata0[262];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNSCore__AtticaProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNSCore__AtticaProvider_t qt_meta_stringdata_KNSCore__AtticaProvider = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KNSCore::AtticaProvider"
QT_MOC_LITERAL(1, 24, 14), // "providerLoaded"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 16), // "Attica::Provider"
QT_MOC_LITERAL(4, 57, 8), // "provider"
QT_MOC_LITERAL(5, 66, 22), // "listOfCategoriesLoaded"
QT_MOC_LITERAL(6, 89, 16), // "Attica::BaseJob*"
QT_MOC_LITERAL(7, 106, 22), // "categoryContentsLoaded"
QT_MOC_LITERAL(8, 129, 3), // "job"
QT_MOC_LITERAL(9, 133, 18), // "downloadItemLoaded"
QT_MOC_LITERAL(10, 152, 20), // "accountBalanceLoaded"
QT_MOC_LITERAL(11, 173, 32), // "authenticationCredentialsMissing"
QT_MOC_LITERAL(12, 206, 8), // "Provider"
QT_MOC_LITERAL(13, 215, 14), // "votingFinished"
QT_MOC_LITERAL(14, 230, 17), // "becomeFanFinished"
QT_MOC_LITERAL(15, 248, 13) // "detailsLoaded"

    },
    "KNSCore::AtticaProvider\0providerLoaded\0"
    "\0Attica::Provider\0provider\0"
    "listOfCategoriesLoaded\0Attica::BaseJob*\0"
    "categoryContentsLoaded\0job\0"
    "downloadItemLoaded\0accountBalanceLoaded\0"
    "authenticationCredentialsMissing\0"
    "Provider\0votingFinished\0becomeFanFinished\0"
    "detailsLoaded"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNSCore__AtticaProvider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x08 /* Private */,
       5,    1,   62,    2, 0x08 /* Private */,
       7,    1,   65,    2, 0x08 /* Private */,
       9,    1,   68,    2, 0x08 /* Private */,
      10,    1,   71,    2, 0x08 /* Private */,
      11,    1,   74,    2, 0x08 /* Private */,
      13,    1,   77,    2, 0x08 /* Private */,
      14,    1,   80,    2, 0x08 /* Private */,
      15,    1,   83,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    8,
    QMetaType::Void, 0x80000000 | 6,    8,
    QMetaType::Void, 0x80000000 | 6,    8,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    8,
    QMetaType::Void, 0x80000000 | 6,    8,

       0        // eod
};

void KNSCore::AtticaProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AtticaProvider *_t = static_cast<AtticaProvider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->providerLoaded((*reinterpret_cast< const Attica::Provider(*)>(_a[1]))); break;
        case 1: _t->listOfCategoriesLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 2: _t->categoryContentsLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 3: _t->downloadItemLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 4: _t->accountBalanceLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 5: _t->authenticationCredentialsMissing((*reinterpret_cast< const Provider(*)>(_a[1]))); break;
        case 6: _t->votingFinished((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 7: _t->becomeFanFinished((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        case 8: _t->detailsLoaded((*reinterpret_cast< Attica::BaseJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Attica::BaseJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KNSCore::AtticaProvider::staticMetaObject = {
    { &Provider::staticMetaObject, qt_meta_stringdata_KNSCore__AtticaProvider.data,
      qt_meta_data_KNSCore__AtticaProvider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNSCore::AtticaProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSCore::AtticaProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNSCore__AtticaProvider.stringdata0))
        return static_cast<void*>(this);
    return Provider::qt_metacast(_clname);
}

int KNSCore::AtticaProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Provider::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
