#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'downloadwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOWNLOADWIDGET_H
#define UI_DOWNLOADWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kratingwidget.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "ktitlewidget.h"
#include "ui/imagepreviewwidget_p.h"
#include "ui/itemsview_p.h"
#include "ui/progressindicator_p.h"

QT_BEGIN_NAMESPACE

class Ui_DownloadWidget
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *m_titleWidget;
    QStackedWidget *detailsStack;
    QWidget *overviewPage;
    QHBoxLayout *horizontalLayout_2;
    KNS3::ItemsView *m_listView;
    QGridLayout *gridLayout_2;
    QLabel *m_providerLabel;
    KComboBox *m_providerCombo;
    QLabel *m_categoryLabel;
    KComboBox *m_categoryCombo;
    QRadioButton *newestRadio;
    QRadioButton *ratingRadio;
    QRadioButton *mostDownloadsRadio;
    QRadioButton *installedRadio;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer;
    QLabel *orderLabel;
    QLabel *label_4;
    QSpacerItem *verticalSpacer_4;
    KLineEdit *m_searchEdit;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *iconViewButton;
    QPushButton *listViewButton;
    QWidget *detailsPage;
    QHBoxLayout *horizontalLayout_7;
    QScrollArea *descriptionScrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout;
    KNS3::ImagePreviewWidget *preview1;
    KNS3::ImagePreviewWidget *preview2;
    KNS3::ImagePreviewWidget *preview3;
    QWidget *widget;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QLabel *authorLabel;
    QLabel *homepageLabel;
    QHBoxLayout *horizontalLayout_6;
    KRatingWidget *ratingWidget;
    QSpacerItem *horizontalSpacer_3;
    QLabel *descriptionLabel;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *verticalSpacer_7;
    KNS3::ImagePreviewWidget *previewBig;
    QSpacerItem *previewSpacer;
    QHBoxLayout *horizontalLayout;
    QPushButton *backButton;
    KNS3::ProgressIndicator *progressIndicator;
    QPushButton *updateButton;
    QPushButton *uninstallButton;
    QPushButton *becomeFanButton;
    QPushButton *installButton;
    QPushButton *closeButton;

    void setupUi(QWidget *DownloadWidget)
    {
        if (DownloadWidget->objectName().isEmpty())
            DownloadWidget->setObjectName(QStringLiteral("DownloadWidget"));
        DownloadWidget->resize(724, 490);
        verticalLayout = new QVBoxLayout(DownloadWidget);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        m_titleWidget = new KTitleWidget(DownloadWidget);
        m_titleWidget->setObjectName(QStringLiteral("m_titleWidget"));

        verticalLayout->addWidget(m_titleWidget);

        detailsStack = new QStackedWidget(DownloadWidget);
        detailsStack->setObjectName(QStringLiteral("detailsStack"));
        overviewPage = new QWidget();
        overviewPage->setObjectName(QStringLiteral("overviewPage"));
        horizontalLayout_2 = new QHBoxLayout(overviewPage);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        m_listView = new KNS3::ItemsView(overviewPage);
        m_listView->setObjectName(QStringLiteral("m_listView"));
        m_listView->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_listView->sizePolicy().hasHeightForWidth());
        m_listView->setSizePolicy(sizePolicy);
        m_listView->setMouseTracking(true);
        m_listView->setSelectionMode(QAbstractItemView::NoSelection);
        m_listView->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        horizontalLayout_2->addWidget(m_listView);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout_2->setContentsMargins(10, -1, -1, -1);
        m_providerLabel = new QLabel(overviewPage);
        m_providerLabel->setObjectName(QStringLiteral("m_providerLabel"));

        gridLayout_2->addWidget(m_providerLabel, 1, 0, 1, 4);

        m_providerCombo = new KComboBox(overviewPage);
        m_providerCombo->setObjectName(QStringLiteral("m_providerCombo"));
        m_providerCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);

        gridLayout_2->addWidget(m_providerCombo, 2, 1, 1, 3);

        m_categoryLabel = new QLabel(overviewPage);
        m_categoryLabel->setObjectName(QStringLiteral("m_categoryLabel"));

        gridLayout_2->addWidget(m_categoryLabel, 4, 0, 1, 4);

        m_categoryCombo = new KComboBox(overviewPage);
        m_categoryCombo->setObjectName(QStringLiteral("m_categoryCombo"));

        gridLayout_2->addWidget(m_categoryCombo, 5, 1, 1, 3);

        newestRadio = new QRadioButton(overviewPage);
        newestRadio->setObjectName(QStringLiteral("newestRadio"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(newestRadio->sizePolicy().hasHeightForWidth());
        newestRadio->setSizePolicy(sizePolicy1);
        newestRadio->setChecked(true);

        gridLayout_2->addWidget(newestRadio, 8, 1, 1, 3);

        ratingRadio = new QRadioButton(overviewPage);
        ratingRadio->setObjectName(QStringLiteral("ratingRadio"));
        ratingRadio->setEnabled(true);

        gridLayout_2->addWidget(ratingRadio, 9, 1, 1, 3);

        mostDownloadsRadio = new QRadioButton(overviewPage);
        mostDownloadsRadio->setObjectName(QStringLiteral("mostDownloadsRadio"));

        gridLayout_2->addWidget(mostDownloadsRadio, 10, 1, 1, 3);

        installedRadio = new QRadioButton(overviewPage);
        installedRadio->setObjectName(QStringLiteral("installedRadio"));

        gridLayout_2->addWidget(installedRadio, 11, 1, 1, 3);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_2->addItem(verticalSpacer_2, 3, 1, 1, 3);

        verticalSpacer_3 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 6, 1, 1, 3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 15, 1, 1, 3);

        orderLabel = new QLabel(overviewPage);
        orderLabel->setObjectName(QStringLiteral("orderLabel"));
        QSizePolicy sizePolicy2(QSizePolicy::Maximum, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(orderLabel->sizePolicy().hasHeightForWidth());
        orderLabel->setSizePolicy(sizePolicy2);
        orderLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_2->addWidget(orderLabel, 7, 0, 1, 4);

        label_4 = new QLabel(overviewPage);
        label_4->setObjectName(QStringLiteral("label_4"));

        gridLayout_2->addWidget(label_4, 13, 0, 1, 4);

        verticalSpacer_4 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_2->addItem(verticalSpacer_4, 12, 1, 1, 3);

        m_searchEdit = new KLineEdit(overviewPage);
        m_searchEdit->setObjectName(QStringLiteral("m_searchEdit"));
        m_searchEdit->setProperty("showClearButton", QVariant(true));

        gridLayout_2->addWidget(m_searchEdit, 14, 1, 1, 3);

        horizontalSpacer_2 = new QSpacerItem(9, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 3, 0, 1, 1);

        iconViewButton = new QPushButton(overviewPage);
        iconViewButton->setObjectName(QStringLiteral("iconViewButton"));
        iconViewButton->setCheckable(true);

        gridLayout_2->addWidget(iconViewButton, 0, 3, 1, 1);

        listViewButton = new QPushButton(overviewPage);
        listViewButton->setObjectName(QStringLiteral("listViewButton"));
        listViewButton->setCheckable(true);
        listViewButton->setChecked(true);
        listViewButton->setFlat(false);

        gridLayout_2->addWidget(listViewButton, 0, 2, 1, 1);


        horizontalLayout_2->addLayout(gridLayout_2);

        detailsStack->addWidget(overviewPage);
        m_listView->raise();
        detailsPage = new QWidget();
        detailsPage->setObjectName(QStringLiteral("detailsPage"));
        horizontalLayout_7 = new QHBoxLayout(detailsPage);
        horizontalLayout_7->setObjectName(QStringLiteral("horizontalLayout_7"));
        descriptionScrollArea = new QScrollArea(detailsPage);
        descriptionScrollArea->setObjectName(QStringLiteral("descriptionScrollArea"));
        descriptionScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName(QStringLiteral("scrollAreaWidgetContents"));
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 684, 392));
        gridLayout = new QGridLayout(scrollAreaWidgetContents);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        preview1 = new KNS3::ImagePreviewWidget(scrollAreaWidgetContents);
        preview1->setObjectName(QStringLiteral("preview1"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Maximum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(preview1->sizePolicy().hasHeightForWidth());
        preview1->setSizePolicy(sizePolicy3);
        preview1->setMinimumSize(QSize(100, 0));
        preview1->setMaximumSize(QSize(100, 100));

        gridLayout->addWidget(preview1, 0, 0, 1, 1);

        preview2 = new KNS3::ImagePreviewWidget(scrollAreaWidgetContents);
        preview2->setObjectName(QStringLiteral("preview2"));
        sizePolicy3.setHeightForWidth(preview2->sizePolicy().hasHeightForWidth());
        preview2->setSizePolicy(sizePolicy3);
        preview2->setMinimumSize(QSize(100, 0));
        preview2->setMaximumSize(QSize(100, 100));

        gridLayout->addWidget(preview2, 0, 1, 1, 1);

        preview3 = new KNS3::ImagePreviewWidget(scrollAreaWidgetContents);
        preview3->setObjectName(QStringLiteral("preview3"));
        sizePolicy3.setHeightForWidth(preview3->sizePolicy().hasHeightForWidth());
        preview3->setSizePolicy(sizePolicy3);
        preview3->setMinimumSize(QSize(100, 0));
        preview3->setMaximumSize(QSize(100, 100));

        gridLayout->addWidget(preview3, 0, 2, 1, 1);

        widget = new QWidget(scrollAreaWidgetContents);
        widget->setObjectName(QStringLiteral("widget"));
        QSizePolicy sizePolicy4(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy4);
        gridLayout_3 = new QGridLayout(widget);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        label = new QLabel(widget);
        label->setObjectName(QStringLiteral("label"));
        QSizePolicy sizePolicy5(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy5);

        horizontalLayout_3->addWidget(label);

        authorLabel = new QLabel(widget);
        authorLabel->setObjectName(QStringLiteral("authorLabel"));
        sizePolicy4.setHeightForWidth(authorLabel->sizePolicy().hasHeightForWidth());
        authorLabel->setSizePolicy(sizePolicy4);
        authorLabel->setOpenExternalLinks(true);

        horizontalLayout_3->addWidget(authorLabel);


        gridLayout_3->addLayout(horizontalLayout_3, 0, 0, 1, 1);

        homepageLabel = new QLabel(widget);
        homepageLabel->setObjectName(QStringLiteral("homepageLabel"));
        homepageLabel->setOpenExternalLinks(true);

        gridLayout_3->addWidget(homepageLabel, 1, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        ratingWidget = new KRatingWidget(widget);
        ratingWidget->setObjectName(QStringLiteral("ratingWidget"));
        ratingWidget->setMinimumSize(QSize(0, 10));
        ratingWidget->setAutoFillBackground(false);

        horizontalLayout_6->addWidget(ratingWidget);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_3);


        gridLayout_3->addLayout(horizontalLayout_6, 3, 0, 1, 1);

        descriptionLabel = new QLabel(widget);
        descriptionLabel->setObjectName(QStringLiteral("descriptionLabel"));
        QSizePolicy sizePolicy6(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(descriptionLabel->sizePolicy().hasHeightForWidth());
        descriptionLabel->setSizePolicy(sizePolicy6);
        descriptionLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        descriptionLabel->setWordWrap(true);

        gridLayout_3->addWidget(descriptionLabel, 5, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 12, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_3->addItem(verticalSpacer_6, 2, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 12, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_3->addItem(verticalSpacer_7, 4, 0, 1, 1);


        gridLayout->addWidget(widget, 0, 3, 3, 1);

        previewBig = new KNS3::ImagePreviewWidget(scrollAreaWidgetContents);
        previewBig->setObjectName(QStringLiteral("previewBig"));
        sizePolicy3.setHeightForWidth(previewBig->sizePolicy().hasHeightForWidth());
        previewBig->setSizePolicy(sizePolicy3);
        previewBig->setMinimumSize(QSize(300, 100));
        previewBig->setMaximumSize(QSize(300, 300));

        gridLayout->addWidget(previewBig, 1, 0, 1, 3);

        previewSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(previewSpacer, 2, 1, 1, 1);

        descriptionScrollArea->setWidget(scrollAreaWidgetContents);

        horizontalLayout_7->addWidget(descriptionScrollArea);

        detailsStack->addWidget(detailsPage);

        verticalLayout->addWidget(detailsStack);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        backButton = new QPushButton(DownloadWidget);
        backButton->setObjectName(QStringLiteral("backButton"));

        horizontalLayout->addWidget(backButton);

        progressIndicator = new KNS3::ProgressIndicator(DownloadWidget);
        progressIndicator->setObjectName(QStringLiteral("progressIndicator"));
        QSizePolicy sizePolicy7(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(20);
        sizePolicy7.setHeightForWidth(progressIndicator->sizePolicy().hasHeightForWidth());
        progressIndicator->setSizePolicy(sizePolicy7);
        progressIndicator->setMinimumSize(QSize(0, 20));
        progressIndicator->setMaximumSize(QSize(16777215, 20));
        progressIndicator->setFrameShape(QFrame::NoFrame);
        progressIndicator->setFrameShadow(QFrame::Raised);
        progressIndicator->setLineWidth(1);

        horizontalLayout->addWidget(progressIndicator);

        updateButton = new QPushButton(DownloadWidget);
        updateButton->setObjectName(QStringLiteral("updateButton"));
        updateButton->setEnabled(true);

        horizontalLayout->addWidget(updateButton);

        uninstallButton = new QPushButton(DownloadWidget);
        uninstallButton->setObjectName(QStringLiteral("uninstallButton"));
        uninstallButton->setEnabled(true);

        horizontalLayout->addWidget(uninstallButton);

        becomeFanButton = new QPushButton(DownloadWidget);
        becomeFanButton->setObjectName(QStringLiteral("becomeFanButton"));

        horizontalLayout->addWidget(becomeFanButton);

        installButton = new QPushButton(DownloadWidget);
        installButton->setObjectName(QStringLiteral("installButton"));

        horizontalLayout->addWidget(installButton);

        closeButton = new QPushButton(DownloadWidget);
        closeButton->setObjectName(QStringLiteral("closeButton"));

        horizontalLayout->addWidget(closeButton);


        verticalLayout->addLayout(horizontalLayout);

#ifndef UI_QT_NO_SHORTCUT
        m_providerLabel->setBuddy(m_providerCombo);
        m_categoryLabel->setBuddy(m_categoryCombo);
        label_4->setBuddy(m_searchEdit);
#endif // QT_NO_SHORTCUT

        retranslateUi(DownloadWidget);

        detailsStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DownloadWidget);
    } // setupUi

    void retranslateUi(QWidget *DownloadWidget)
    {
        m_providerLabel->setText(tr2i18n("Provider:", Q_NULLPTR));
        m_categoryLabel->setText(tr2i18n("Category:", Q_NULLPTR));
        newestRadio->setText(tr2i18n("Newest", Q_NULLPTR));
        ratingRadio->setText(tr2i18n("Rating", Q_NULLPTR));
        mostDownloadsRadio->setText(tr2i18n("Most downloads", Q_NULLPTR));
        installedRadio->setText(tr2i18n("Installed", Q_NULLPTR));
        orderLabel->setText(tr2i18n("Order by:", Q_NULLPTR));
        label_4->setText(tr2i18n("Search:", Q_NULLPTR));
        m_searchEdit->setPlaceholderText(tr2i18n("Enter search phrase here", Q_NULLPTR));
        label->setText(tr2i18n("Author:", Q_NULLPTR));
        authorLabel->setText(QString());
        homepageLabel->setText(tr2i18n("<a href=\"http://opendesktop.org\">Homepage</a>", Q_NULLPTR));
        descriptionLabel->setText(QString());
        updateButton->setText(tr2i18n("Update", Q_NULLPTR));
        uninstallButton->setText(tr2i18n("Uninstall", Q_NULLPTR));
        becomeFanButton->setText(tr2i18n("Become a Fan", Q_NULLPTR));
        installButton->setText(tr2i18n("Install", Q_NULLPTR));
        Q_UNUSED(DownloadWidget);
    } // retranslateUi

};

namespace Ui {
    class DownloadWidget: public Ui_DownloadWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DOWNLOADWIDGET_H

